function G_x = Green_incl_g_x(a,b,c,d,theta,x,y)
%
% Provides the Green's function g_x (for displacements u_x) analytically integrated over a
% rectangular reservoir domain crossed by an inclined displaced fault. The integral is
% splitted in four domains: 1) rectangle to the left of the fault, 2) triangle to the left,
% 3) triangle to  the right, and 4) rectangle to the right. 
%
% Jan Dirk Jansen, TU Delft, December 2018
%

small = 1e-9; % small number to modify input parameters (to avoid function evaluations at
              % singularities) [-]  

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
if theta == 0
    if x == 0
        x = x + small*abs(d);
    end
else
    if x == y/tan(theta)
        x = x + small*abs(d);
    end
end
if x == d
    x = x + small*abs(d);
end
if x == -c 
    x = x - small*abs(c);
end
if y == a || y == b
    y = y + small*abs(b-a);
end
if y == -a || y == -b
    y = y - small*abs(b-a);
end

% Compute integrals:
f = b/tan(theta);
G_x_1 =  g_x_int_square(-c,-f,-b,a,x,y);
G_x_2 = -g_x_int_triang(-b,a,theta,-x,-y); % makes use of symmetry
G_x_3 =  g_x_int_triang(-b,a,theta,x,y);
G_x_4 =  g_x_int_square(f,d,-a,b,x,y);

G_x = G_x_1 + G_x_2 + G_x_3 + G_x_4;

