function G_xx = Green_incl_g_xx_inf(a,b,theta,x,y)
%
% Provides the Green's function g_xx (for normal stresses sigma_xx) analytically integrated
% over an infinite reservoir domain crossed by an inclined displaced fault. The integral is
% split in four domains: 1) rectangle to the left of the fault, 2)
% rectangle to the right, 3) triangle to the left of the fault, 4) triangle to the right of the fault
%
% Jan Dirk Jansen, TU Delft, November 2018
%
if abs(y*cot(theta) - x) < 1e-12
     x = y*cot(theta)  ;
end
small = 1e-9; % small number to modify input parameters (to avoid function evaluations at
% singularities) [-]

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero):
if y == a || y == b
    y = y+small*abs(b-a);
end
if y == -a || y == -b
    y = y-small*abs(b-a);
end

% Manually simplified symbolic output for limiting case of an infinite reservoir:
G_xx = (sin(theta)*cos(theta)/2) *...
    log((((y-a)^2+(x-a*cot(theta))^2)*((y+a)^2+(x+a*cot(theta))^2)) ...
    /    (((y-b)^2+(x-b*cot(theta))^2)*((y+b)^2+(x+b*cot(theta))^2)))...
   -(sin(theta))^2 ...
    * (atan((y+a +cot(theta)*(x+a*cot(theta)))/(y*cot(theta)-x)) ...
   - atan((y-b +cot(theta)*(x-b*cot(theta)))/(y*cot(theta)-x))...
   + atan((y-a +cot(theta)*(x-a*cot(theta)))/(y*cot(theta)-x)) ...
   - atan((y+b +cot(theta)*(x+b*cot(theta)))/(y*cot(theta)-x)));
