function G_yy = Green_incl_g_yy(a,b,c,d,theta,x,y)
%
% Provides the Green's function g_yy (for stress sigma_yy) analytically integrated over a
% rectangular reservoir domain crossed by an inclined displaced fault. The integral is
% split in four domains: 1) rectangle to the left of the fault, 2)
% rectangle to the right, 3) triangle to the left of the fault, 4) triangle to the right of the fault 
%
% Jan Dirk Jansen, TU Delft, November 2018
%

small = 1e-9; % small number to modify input parameters (to avoid function evaluations at
              % singularities) [-]  

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
if x == 0 || x == d
    x = x + small*abs(d);
end
if x == -c 
    x = x - small*abs(c);
end
if y == a || y == b
    y = y + small*abs(b-a);
end
if y == -a || y == -b
    y = y - small*abs(b-a);
end

% Compute integrals:
f = b/tan(theta);
e = a/tan(theta);

G_yy_1 = g_yy_int_square(-c,-f,-b,a,x,y);
G_yy_2  = g_yy_int_triang(-e,f,-a,b,-x,-y);
G_yy_3 = g_yy_int_triang(-e,f,-a,b,x,y);
G_yy_4 = g_yy_int_square(f,d,-a,b,x,y);

G_yy = G_yy_1 + G_yy_2 + G_yy_3 + G_yy_4;



