function G_yy = Green_incl_g_yy_inf(a,b,theta,x,y)
%
% Provides the Green's function g_yy (for normal stresses sigma_yy) analytically integrated
% over an infinite reservoir domain crossed by an inclined displaced fault. The integral is
% split in four domains: 1) rectangle to the left of the fault, 2)
% rectangle to the right, 3) triangle to the left of the fault, 4) triangle to the right of the fault
%
% Jan Dirk Jansen, TU Delft, November 2018
%
 if abs(y-x*tan(theta)) < 1e-12
     y= x*tan(theta);
 end
 small = 1e-9; % small number to modify input parameters (to avoid function evaluations at
% singularities) [-]

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero):
if y == a || y == b
    y = y+small*abs(b-a);
end
if y == -a || y == -b
    y = y-small*abs(b-a);
end
% Manually simplified symbolic output for limiting case of an infinite reservoir:
G_yy =  atan((x -a*cot(theta))/(y-a))-atan((x -b*cot(theta))/(y-b))...
   +    atan((x +a*cot(theta))/(y+a))-atan((x +b*cot(theta))/(y+b))...
   + (pi/2)* (sign(y+a)-sign(y-a)+sign(y+b) -sign(y-b))...
   + (sin(theta)*cos(theta)/2) *...
     log((((y-b)^2+(x-(b*cot(theta)))^2)*((y+b)^2 +(x+ (b*cot(theta)))^2)) ...
    /    (((y-a)^2+(x-(a*cot(theta)))^2)*((y+a)^2 +(x+ (a*cot(theta)))^2))) ...
   -((cos(theta)) ^2) ...
   * (atan((x*tan(theta)+a+tan(theta)^2 * (y+a))/ (tan(theta)*(y-x*tan(theta))))...
   -  atan((x*tan(theta)-b+tan(theta)^2 * (y-b))/ (tan(theta)*(y-x*tan(theta))))...
   +  atan((x*tan(theta)-a+tan(theta)^2 * (y-a))/ (tan(theta)*(y-x*tan(theta))))...
   -  atan((x*tan(theta)+b+tan(theta)^2 * (y+b))/ (tan(theta)*(y-x*tan(theta)))));