function G_as_xy = Green_vert_g_as_xy(a,b,C,chi_hi,chi_lo,mu,nu,sigma_xy_0,...
    sigma_xx_eff_0,x,y)
%
% Provides the Green's function g^as_xy (for shear stresses sigma_xy) numerically
% integrated over a slipping segment with chi_lo < chi < chi_hi of a vertical
% displaced fault to compensate for the excess shear stress. Only valid for an infinite
% reservoir. 
%
% Jan Dirk Jansen, TU Delft, February 2019
%

% Set control parameters:
n_int = 500; % number of integration points for chi_lo < chi < chi_hi, -
small = 1e-6; % small number to modify input parameters (to avoid function evaluations at
% singularities)

%C = -C; %%%

% Perform integration:
Delta_chi = (chi_hi - chi_lo) / n_int; % step size for numerical integration, m
G_as_xy = 0;
chi = - Delta_chi/2; % chi is the local y coordinate along the fault
for j=1:n_int-1
    chi = chi + Delta_chi; % rectangular integration with mid-point values
    % Check if x or y corresponds to a singularity and if so, perturb the values:
    if abs(chi) == a || abs(chi) == b
        chi = chi - small;
    end
    R = sqrt(x^2+(y-chi)^2);
    G = 6.5e9;
    g_as_xy = -(1/G) * ((y-chi)^2-x^2) / R^4;
        % Green's function for excess fault stress correction, 1/m
    G_xy = (1/2) * log( ( (chi-a)^2*(chi+a)^2 ) ...
        / ( (chi-b)^2*(chi+b)^2 ) ); % integrated Green's function for sigma_xy
    sigma_xy = C * G_xy; % incremental shear stress
    sigma_hat_xy = sigma_xy_0 + sigma_xy; % combined initial and incremental shear stress
    sigma_sl = get_sigma_slip_right(a,b,C,mu,nu,sigma_xx_eff_0,chi); % right slip boundary
    sigma_ex_xy = sigma_hat_xy - sigma_sl; % excess shear stress
    Delta_G_as_xy = sigma_ex_xy * g_as_xy * Delta_chi; % increment in numerical integration
    G_as_xy = G_as_xy + Delta_G_as_xy; % increment in numerical integration
end