function G_x = Green_vert_g_x(a,b,c,d,x,y)
%
% Provides the Green's function g_x (for displacements u_x) analytically integrated over a
% rectangular reservoir domain crossed by a vertical displaced fault. The integral is
% splitted in two domains: 1) rectangle to the left of the fault, 2) rectangle to the right.
%
% Jan Dirk Jansen, TU Delft, August 2018
%

small = 1e-9; % small number to modify input parameters (to avoid function evaluations at
              % singularities) [-]  

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
if x == 0 || x == d
    x = x + small*abs(d);
end
if x == -c 
    x = x - small*abs(c);
end
if y == a || y == b
    y = y + small*abs(b-a);
end
if y == -a || y == -b
    y = y - small*abs(b-a);
end

% % % Original symbolic output (as taken from Matlab command window):
% % G_x_1 = ...
% %     (x*(atan((b + y)/(c + x)) - atan((b + y)/x) ...
% %     + atan((a - y)/(c + x)) - atan((a - y)/x)))/2 ...
% %     + (a*log(a^2 - 2*a*y + c^2 + 2*c*x + x^2 + y^2))/4 ...
% %     + (b*log(b^2 + 2*b*y + c^2 + 2*c*x + x^2 + y^2))/4 ...
% %     - (a*log(a^2 - 2*a*y + x^2 + y^2))/4 ...
% %     - (b*log(b^2 + 2*b*y + x^2 + y^2))/4 ...
% %     - (y*log(a^2 - 2*a*y + c^2 + 2*c*x + x^2 + y^2))/4 ...
% %     + (y*log(b^2 + 2*b*y + c^2 + 2*c*x + x^2 + y^2))/4 ...
% %     + (y*log(a^2 - 2*a*y + x^2 + y^2))/4 ...
% %     - (y*log(b^2 + 2*b*y + x^2 + y^2))/4 ...
% %     + (c*(atan((b + y)/(c + x)) + atan((a - y)/(c + x))))/2 ...
% %     - (atan((a - y)/x))/2;
 
% % G_x_4 =...
% %     (a*log(a^2 + 2*a*y + x^2 + y^2))/4 ...
% %     - (b*log(b^2 - 2*b*y + d^2 - 2*d*x + x^2 + y^2))/4 ...
% %     - (a*log(a^2 + 2*a*y + d^2 - 2*d*x + x^2 + y^2))/4 ...
% %     + (b*log(b^2 - 2*b*y + x^2 + y^2))/4 ...
% %     - (y*log(a^2 + 2*a*y + d^2 - 2*d*x + x^2 + y^2))/4 ...
% %     + (y*log(b^2 - 2*b*y + d^2 - 2*d*x + x^2 + y^2))/4 ...
% %     + (y*log(a^2 + 2*a*y + x^2 + y^2))/4 ...
% %     - (y*log(b^2 - 2*b*y + x^2 + y^2))/4 ...
% %     - (d*(atan((b - y)/(d - x)) + atan((a + y)/(d - x))))/2 ...
% %     + (atan((a + y)/(-x)))/2 ...
% %     + (x*(atan((b - y)/(d - x)) - atan((b - y)/(-x)) ...
% %     + atan((a + y)/(d - x)) - atan((a + y)/(-x))))/2;

% Manually simplified symbolic output:
G_x_1 = g_x_int_square(-c,0,-b,a,x,y);
G_x_4 = g_x_int_square(0,d,-a,b,x,y);

G_x = G_x_1 + G_x_4;

