function G_x = Green_vert_g_x_inf(a,b,x,y)
%
% Provides the Green's function g_x (for displacements u_x) analytically integrated over an
% infinite reservoir domain crossed by a vertical displaced fault. The integral is
% splitted in two domains: 1) reservoir to the left of the fault, 2) reservoir to the right.
%
% Jan Dirk Jansen, TU Delft, November 2018
%

small = 1e-9; % small number to modify input parameters (to avoid function evaluations at
              % singularities) [-]  

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
if y == a || y == b
    y = y + small*abs(b-a);
end
if y == -a || y == -b
    y = y - small*abs(b-a);
end

% Manually simplified symbolic output for limiting case of an infinite reservoir:
G_x_1 = ...
        log(x^2+(y-a)^2)*(y-a)/4 ...
      - log(x^2+(y+b)^2)*(y+b)/4 ...
      - atan2((a+b)*x,(x^2+(y-a)*(y+b))) * x/2;
  
G_x_4 = ...
      + log(x^2+(y+a)^2)*(y+a)/4 ...
      - log(x^2+(y-b)^2)*(y-b)/4 ...
      + atan2((a+b)*x,(x^2+(y-b)*(y+a))) * x/2;

G_x = G_x_1 + G_x_4;


