function G_xx = Green_vert_g_xx(a,b,c,d,x,y)
%
% Provides the Green's function g_xx (for stress sigma_xx) analytically integrated over a
% rectangular reservoir domain crossed by a vertical displaced fault. The integral is
% splitted in two domains: 1) rectangle to the left of the fault, 2) rectangle to the right.
%
% Jan Dirk Jansen, TU Delft, November 2018
%

small = 1e-9; % small number to modify input parameters (to avoid function evaluations at
              % singularities) [-]  

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
if x == 0 || x == d
    x = x + small*abs(d);
end
if x == -c 
    x = x - small*abs(c);
end
if y == a || y == b
    y = y + small*abs(b-a);
end
if y == -a || y == -b
    y = y - small*abs(b-a);
end

% Integrate:
G_xx_1 = g_xx_int_square(-c,0,-b,a,x,y);
G_xx_4 = g_xx_int_square(0,d,-a,b,x,y);

G_xx = G_xx_1 + G_xx_4;

