function G_xy = Green_vert_g_xy(a,b,c,d,x,y)
%
% Provides the Green's function g_xy (for stress sigma_xy) analytically integrated over a
% rectangular reservoir domain crossed by a vertical displaced fault. The integral is
% splitted in two domains: 1) rectangle to the left of the fault, 2) rectangle to the right.
%
% Jan Dirk Jansen, TU Delft, November 2018
%

small = 1e-9; % small number to modify input parameters (to avoid function evaluations at
              % singularities) [-]  

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
if x == 0 || x == d
    x = x + small*abs(d);
end
if x == -c 
    x = x - small*abs(c);
end
if y == a || y == b
    y = y + small*abs(b-a);
end
if y == -a || y == -b
    y = y - small*abs(b-a);
end

% Integrate:
G_xy_1 = g_xy_int_square(-c,0,-b,a,x,y);
G_xy_4 = g_xy_int_square(0,d,-a,b,x,y);

G_xy = G_xy_1 + G_xy_4;

