function [G_norm_1,G_norm_2,G_norm_3,...
    G_norm_minus2pi_1,G_norm_minus2pi_2,G_norm_minus2pi_3,...
    G_shear_1,G_shear_2,G_shear_3,...
    p_0,p_20,...
    sigma_norm_0,sigma_norm_1,sigma_norm_2,sigma_norm_3,...
    sigma_shear_0,sigma_shear_1,sigma_shear_2,sigma_shear_3,y] = ...
    disp_fault_num_check(a,alpha,b,C,D_center,g,K_eff,n_pt_y_2,p_0_center,p_20_inc,phi,...
    rho_f,rho_s,theta,y_plot_max,y_plot_min)
%
% Computes stresses at the fault.
%

small = 1e-9;
Dy_2 = (y_plot_max - y_plot_min)/n_pt_y_2;
y = zeros(n_pt_y_2,1);
G_norm_1 = zeros(n_pt_y_2,1);
G_norm_2 = zeros(n_pt_y_2,1);
G_norm_3 = zeros(n_pt_y_2,1);
G_norm_minus2pi_1 = zeros(n_pt_y_2,1);
G_norm_minus2pi_2 = zeros(n_pt_y_2,1);
G_norm_minus2pi_3 = zeros(n_pt_y_2,1);
G_shear_1 = zeros(n_pt_y_2,1);
G_shear_2 = zeros(n_pt_y_2,1);
G_shear_3 = zeros(n_pt_y_2,1);
sigma_norm_0 = zeros(n_pt_y_2,1);
sigma_shear_0 = zeros(n_pt_y_2,1);
p_0 = zeros(n_pt_y_2,1);
p_20 = zeros(n_pt_y_2,1);

% Compute gradient:
rho = ( (1-phi)*rho_s + phi*rho_f );
% D_center_check = p_0_center/(rho_f*g)
sigma_v_0_center = -rho * g * D_center;
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
    p_0(i) = p_0_center - rho_f * g * y(i);  
    if (-a < y(i) && y(i) < b)
        p_20(i) = p_0(i) + p_20_inc;  
    else
        p_20(i) = p_0(i); 
    end
    sigma_v_0 = sigma_v_0_center + ( (1-phi)*rho_s + phi*rho_f ) * g * y(i);  
    sigma_v_eff_0 = sigma_v_0 + alpha * p_0(i);
    sigma_h_eff_0 = K_eff * sigma_v_eff_0;
    sigma_h_0 = sigma_h_eff_0 - alpha * p_0(i);
    sigma_norm_0(i)  = sigma_h_0 * (sin(theta))^2 + sigma_v_0 * (cos(theta))^2;
    sigma_shear_0(i) = - (sigma_v_0 - sigma_h_0) * sin(theta) * cos(theta);
end
% Option 1: call functions to compute G_xx(x,y), G_yy(x,y) and G_xy(x,y):
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
    x = y(i)*cot(theta) + small;
    G_xx = Green_incl_g_xx_inf(a,b,theta,x,y(i));
    G_yy = Green_incl_g_yy_inf(a,b,theta,x,y(i));
    G_xy = Green_incl_g_xy_inf(a,b,theta,x,y(i));
    G_norm_1(i)  = G_xx * (sin(theta))^2 + G_yy * (cos(theta))^2 - 2*G_xy * sin(theta) * cos(theta);
    if (-a < y(i) && y(i) < b)
        G_norm_minus2pi_1(i) = G_norm_1(i) - 2*pi;
    else
        G_norm_minus2pi_1(i) = G_norm_1(i);    
    end
    G_shear_1(i) = G_xy * ( (sin(theta))^2 - (cos(theta))^2 ) + (G_xx - G_yy) * sin(theta) * cos(theta);
end
% Option 2: use simplified expressions for G_xx(y/tan(theta),y), etc.:
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
    G_xx = (1/2) * log( ((y(i)-a)^2*(y(i)+a)^2)/((y(i)-b)^2*(y(i)+b)^2) ) * sin(theta) * cos(theta) ...
        + (pi/2) * (sign(y(i)+a) + sign(y(i)-a) - sign(y(i)-b) - sign(y(i)+b)) * (sin(theta))^2;
    G_yy = (1/2) * log( ((y(i)-b)^2*(y(i)+b)^2)/((y(i)-a)^2*(y(i)+a)^2) ) * sin(theta) * cos(theta) ...
        + (pi/2) * (sign(y(i)+a) + sign(y(i)-a) - sign(y(i)-b) - sign(y(i)+b)) * (cos(theta))^2 ...
        + (pi/2) * (sign(y(i)+a) - sign(y(i)-a) - sign(y(i)-b) + sign(y(i)+b));
    G_xy = (1/2) * log( ((y(i)-a)^2*(y(i)+a)^2)/((y(i)-b)^2*(y(i)+b)^2) ) * (sin(theta))^2 ...
        - (pi/2) * (sign(y(i)+a) + sign(y(i)-a) - sign(y(i)-b) - sign(y(i)+b)) * sin(theta) * cos(theta);
    G_norm_2(i)  = G_xx * (sin(theta))^2 + G_yy * (cos(theta))^2 - 2*G_xy * sin(theta) * cos(theta);
    if (-a < y(i) && y(i) < b)
        G_norm_minus2pi_2(i) = G_norm_2(i) - 2*pi;
    else
        G_norm_minus2pi_2(i) = G_norm_2(i);     
    end
    G_shear_2(i) = G_xy * ( (sin(theta))^2 - (cos(theta))^2 ) - (G_yy - G_xx) * sin(theta) * cos(theta);    
end
% Option 3: use further simplified expressions for G_norm and G_shear:
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
    G_norm_3(i) = ...
        - 0.5 * log( (y(i)-a)^2*(y(i)+a)^2 / ((y(i)-b)^2*(y(i)+b)^2) ) ...
        * sin(theta) * cos(theta) ...
        - (pi/2) * (sign(y(i)+b) - sign(y(i)-a)) ...
        * (sin(theta))^2 ...
        + (pi/2) * (sign(y(i)+a) - sign(y(i)-b)) ...
        * ( 1 + (cos(theta))^2 );
    if (-a < y(i) && y(i) < b)
        G_norm_minus2pi_3(i) = G_norm_3(i) - 2*pi;
    else
        G_norm_minus2pi_3(i) = G_norm_3(i);
    end
    G_shear_3(i) = ...
        0.5 * log( (y(i)-a)^2*(y(i)+a)^2 / ((y(i)-b)^2*(y(i)+b)^2) ) * sin(theta)^2 ...
        - (pi/2) * (sign(y(i)+a) - sign(y(i)-a) - sign(y(i)-b) + sign(y(i)+b)) ...
        * sin(theta) * cos(theta);
end
sigma_norm_1 = C * G_norm_minus2pi_1;
sigma_norm_2 = C * G_norm_minus2pi_2;
sigma_norm_3 = C * G_norm_minus2pi_3;
sigma_shear_1 = C * G_shear_1;
sigma_shear_2 = C * G_shear_2;
sigma_shear_3 = C * G_shear_3;

