function disp_fault_num_check
%
% Creates plot of shear stresses along an inclined fault for comparison with numerical results.
%
close all
a = 100;
b = 200;
C = -2.3592e+06; % negative: production
theta = pi/3;
n_pt_y_2 = 10000;
y_plot_max =  300;
y_plot_min = -300;
Dy_2 = (y_plot_max - y_plot_min)/n_pt_y_2;

% Plot sigma_xy for x = y/tan(theta), i.e. at the fault:
y = zeros(n_pt_y_2,1);
G_shear_1 = zeros(n_pt_y_2,1);
G_shear_2 = zeros(n_pt_y_2,1);
G_shear_3 = zeros(n_pt_y_2,1);
sigma_norm_0 = zeros(n_pt_y_2,1);
sigma_shear_0 = zeros(n_pt_y_2,1);
small = 1e-6;

% Compute gradient:
D_center = 3500; % m
g = 9.81; % m/s^2
K_eff = 0.5; % -
p_0_center = 35e6; % Pa
rho_f = 1020; % kg/m^3
rho_s = 2650; % kg/m^3
phi = 0.15; % -
sigma_v_0_center = ( (1-phi)*rho_s + phi*rho_f ) * g * D_center;
p_0_bot = p_0_center + rho_f * g * (a+b)/2;
sigma_v_0_bot = sigma_v_0_center + ( (1-phi)*rho_s + phi*rho_f ) * (a+b)/2;
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
    p_0 = p_0_bot - rho_f * g * y(i);  
    sigma_v_0 = sigma_v_0_bot - ( (1-phi)*rho_s + phi*rho_f ) * g * y(i);  
    sigma_v_eff_0 = sigma_v_0 + p_0;
    sigma_h_eff_0 = K_eff * sigma_v_eff_0;
    sigma_h_0 = sigma_h_eff_0 - p_0;
    sigma_norm_0(i) = sigma_v_0 * sin(theta) + sigma_h_0 * cos(theta);
    sigma_shear_0(i) = sigma_v_0 * cos(theta) + sigma_h_0 * sin(theta);
end
% Option 1: call functions to compute G_xx(x,y), G_yy(x,y) and G_xy(x,y):
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
    x = y(i)*cot(theta);
    G_xx = Green_incl_g_xx_inf(a,b,theta,x,y(i));
    G_yy = Green_incl_g_yy_inf(a,b,theta,x,y(i));
    G_xy = Green_incl_g_xy_inf(a,b,theta,x,y(i));
    G_shear_1(i) = G_xy * ( (sin(theta))^2 - (cos(theta))^2 ) - (G_yy - G_xx) * sin(theta) * cos(theta);    
end
% Option 2: use simplified expressions for G_xx(y/tan(theta),y), etc.:
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
%     x = y(i)/tan(theta) + small;
    G_xx = (1/2) * log( ((y(i)-a)^2*(y(i)+a)^2)/((y(i)-b)^2*(y(i)+b)^2) ) * sin(theta) * cos(theta) ...
        - (pi/2) * (sign(y(i)+a) + sign(y(i)-a) - sign(y(i)-b) - sign(y(i)+b)) * (sin(theta))^2;
    G_yy = (1/2) * log( ((y(i)-b)^2*(y(i)+b)^2)/((y(i)-a)^2*(y(i)+a)^2) ) * sin(theta) * cos(theta) ...
        - (pi/2) * (sign(y(i)+a) + sign(y(i)-a) - sign(y(i)-b) - sign(y(i)+b)) * (cos(theta))^2 ...
        + (pi/2) * (sign(y(i)+a) - sign(y(i)-a) - sign(y(i)-b) + sign(y(i)+b));
%     G_yy = Green_incl_g_yy_inf(a,b,theta,x,y(i));
    G_xy = (1/2) * log( ((y(i)-a)^2*(y(i)+a)^2)/((y(i)-b)^2*(y(i)+b)^2) ) * (sin(theta))^2 ...
        + (pi/2) * (sign(y(i)+a) + sign(y(i)-a) - sign(y(i)-b) - sign(y(i)+b)) * sin(theta) * cos(theta);
%%%    G_xy = Green_incl_g_xy_inf(a,b,theta,x,y(i));
    G_shear_2(i) = G_xy * ( (sin(theta))^2 - (cos(theta))^2 ) - (G_yy - G_xx) * sin(theta) * cos(theta);    
end


%%%Option 3 - G_Shear on fault expression
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
    G_shear_3(i) = ...
        0.5 * log( (y(i)-a)^2*(y(i)+a)^2 / ((y(i)-b)^2*(y(i)+b)^2) ) * sin(theta)^2 ...
        - (pi/2) * (sign(y(i)+a) - sign(y(i)-a) - sign(y(i)-b) + sign(y(i)+b)) ...
        * sin(theta) * cos(theta);                
end
sigma_shear_1 = C * G_shear_1;
sigma_shear_2 = C * G_shear_2;
sigma_shear_3 = C * G_shear_3;


figure
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(sigma_shear_1/1e6,y,'r','LineWidth',1.5) 
hold on
plot(sigma_shear_2/1e6,y,'--b','LineWidth',1.5) 
plot(sigma_shear_3/1e6,y,'-.k','LineWidth',1.5)
legend('Green\_incl\_g_**\_inf Function  ', 'Simplified G_**_onfault ',' Simplified G\_shear expression') 
hold off
xlabel('\rm Shear stresses (MPa)')
ylabel('\ity \rm(m)')
axis([-15 15 -300 300])
box on
%legend('\itp\rm = 0 MPa','\rm = 5 MPa','\rm = 20 MPa','\rm = 35 MPa', 'location','southwest')

figure
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(sigma_shear_0/1e6,y,'k','LineWidth',1.5) 
hold on
plot((sigma_shear_0 + sigma_shear_1)/1e6,y,'r','LineWidth',1.5) 
plot((sigma_shear_0 + sigma_shear_2)/1e6,y,'--b','LineWidth',1.5) 
hold off
xlabel('\rm Shear stresses (MPa)')
ylabel('\ity \rm(m)')
%axis([-15 15 -300 300])
box on
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% sigma_xx_0 = 0; % initial horizontal stress, N/m
% sigma_xy_0 = 0; % initial shear stress, N/m
% n_pt_y_2 = 100000; % [-] higher resolution (gives higher peaks for shear stresses);
% 
% % Plot sigma_xy for x = 0:
% y = zeros(n_pt_y_2,1);
% G_xy_plot_limit_0 = zeros(n_pt_y_2,1);
% for i = 1:n_pt_y_2
%     y(i) = y_plot_min + (i-1)*Dy_2;
%     G_xy_plot_limit_0(i) = 0.5 * log( (y(i)-a)^2*(y(i)+a)^2 / ((y(i)-b)^2*(y(i)+b)^2) );
% end
% sigma_xy_plot_limit_0 = 0 * G_xy_plot_limit_0;
% sigma_xy_plot_limit_5 = (5/20) *C * G_xy_plot_limit_0;
% sigma_xy_plot_limit_20 = (20/20) *C * G_xy_plot_limit_0;
% sigma_xy_plot_limit_35 = (35/20) *C * G_xy_plot_limit_0;
% 
% figure
% plot(sigma_xy_plot_limit_0/1e6,y,'LineWidth',1.5,'Color',[244/255, 175/255, 65/255]) % p = 0
% hold on
% plot(sigma_xy_plot_limit_5/1e6,y,'b','LineWidth',1.5) % p = 5
% plot(sigma_xy_plot_limit_20/1e6,y,'r','LineWidth',1.5) % p = 20
% plot(sigma_xy_plot_limit_35/1e6,y,'g','LineWidth',1.5) % p = 35
% line([0 0],[-300 300],'Color','k') % vertical line at x = 0
% line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
% line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
% line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
% line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
% line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
% % Repeat to get cleaner plot and correct legend:
% plot(sigma_xy_plot_limit_0/1e6,y,'LineWidth',1.5,'Color',[244/255, 175/255, 65/255]) % p = 0
% plot(sigma_xy_plot_limit_5/1e6,y,'b','LineWidth',1.5) % p = 5
% plot(sigma_xy_plot_limit_20/1e6,y,'r','LineWidth',1.5) % p = 20
% plot(sigma_xy_plot_limit_35/1e6,y,'g','LineWidth',1.5) % p = 35
% hold off
% xlabel('\rm Shear stresses (MPa)')
% ylabel('\ity \rm(m)')
% axis([-15 15 -300 300])
% box on
% legend('\itp\rm = 0 MPa','\rm = 5 MPa','\rm = 20 MPa','\rm = 35 MPa', 'location','southwest')
