% Script file disp_fault_num_check_main
%
% Creates plots of stresses along an inclined fault for comparison with numerical results. In
% addition creates lots of other diagnostic plots. The numerical results have been produced by
% Femke Vossepoel with the aid of the Plaxis 2D finite element code.
%
% Jan Dirk Jansen, TU Delft, March - June 2019
% j.d.jansen@tudelft.nl
% 

clear vars
close all

flag_normal = 1; % 0 = reversed fault (150 degrees); 1 = normal fault (60 degrees)

% 1a) Get data for left plot:
flag_inj = 1; % 0 = production; 1 = injection
[mu,p_plax_0_norm_eff_plot_a,p_plax_20_norm_eff_plot_a,...
    p_plax_0_shear_plot_a,p_plax_20_shear_plot_a,...
    sigma_norm_eff_0_a,sigma_norm_eff_3_a,...
    sigma_shear_0_a,sigma_shear_3_a,...
    y_a,y_plax_plot_a] = ...
    disp_fault_num_check_work(flag_inj,flag_normal);

%1b) Get data for right plot:
flag_inj = 0; % 0 = production; 1 = injection
[mu,p_plax_0_norm_eff_plot_b,p_plax_20_norm_eff_plot_b,...
    p_plax_0_shear_plot_b,p_plax_20_shear_plot_b,...
    sigma_norm_eff_0_b,sigma_norm_eff_3_b,...
    sigma_shear_0_b,sigma_shear_3_b,...
    y_b,y_plax_plot_b] = ...
    disp_fault_num_check_work(flag_inj,flag_normal);

% Create plots:
figure
subplot(1,2,1) % left plot
line([0 0],[-300 300],'LineStyle','-','Color','k','LineWidth',0.5) % vertical line at x = 0
hold on
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(mu*sigma_norm_eff_0_a/1e6,y_a,'-','LineWidth',1.5,'Color',[200/255 200/255 200/255]) % left slip boundary
plot(mu*(sigma_norm_eff_0_a+sigma_norm_eff_3_a)/1e6,y_a,'-','LineWidth',1.5,'Color',[110/255 110/255 110/255]) 
plot(-mu*sigma_norm_eff_0_a/1e6,y_a,'-','LineWidth',1.5,'Color',[200/255 200/255 200/255]) % right slip boundary
plot(-mu*(sigma_norm_eff_0_a+sigma_norm_eff_3_a)/1e6,y_a,'-','LineWidth',1.5,'Color',[110/255 110/255 110/255]) 
plot(mu*p_plax_0_norm_eff_plot_a,y_plax_plot_a,'v','LineWidth',1.5,'Color',[200/255 200/255 200/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[200/255 200/255 200/255]) 
plot(mu*p_plax_20_norm_eff_plot_a,y_plax_plot_a,'v','LineWidth',1.5,'Color',[110/255 110/255 110/255],...
        'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[110/255 110/255 110/255]) 
plot(-mu*p_plax_0_norm_eff_plot_a,y_plax_plot_a,'v','LineWidth',1.5,'Color',[200/255 200/255 200/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[200/255 200/255 200/255]) 
plot(-mu*p_plax_20_norm_eff_plot_a,y_plax_plot_a,'v','LineWidth',1.5,'Color',[110/255 110/255 110/255],...
        'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[110/255 110/255 110/255]) 
plot(sigma_shear_0_a/1e6,y_a,'LineWidth',1.5,'Color',[244/255, 175/255, 65/255]) 
plot((sigma_shear_0_a + sigma_shear_3_a)/1e6,y_a,'r','LineWidth',1.5) 
plot(p_plax_0_shear_plot_a,y_plax_plot_a,'v','LineWidth',1.5,'Color',[244/255, 175/255, 65/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[244/255, 175/255, 65/255]) 
plot(p_plax_20_shear_plot_a,y_plax_plot_a,'v','LineWidth',1.5,'Color','r',...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor','r') 
hold off
xlabel('\rm Shear stresses - injection (MPa)')
ylabel('\ity \rm(m)')
if flag_normal == 0
    axis([-45 45 -300 300])
else
    axis([-35 35 -300 300])
end
box on

subplot(1,2,2) % right plot
line([0 0],[-300 300],'LineStyle','-','Color','k','LineWidth',0.5) % vertical line at x = 0
hold on
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(mu*sigma_norm_eff_0_b/1e6,y_b,'-','LineWidth',1.5,'Color',[200/255 200/255 200/255]) % left slip boundary
plot(mu*(sigma_norm_eff_0_b+sigma_norm_eff_3_b)/1e6,y_b,'-','LineWidth',1.5,'Color',[110/255 110/255 110/255]) 
plot(-mu*sigma_norm_eff_0_b/1e6,y_b,'-','LineWidth',1.5,'Color',[200/255 200/255 200/255]) % right slip boundary
plot(-mu*(sigma_norm_eff_0_b+sigma_norm_eff_3_b)/1e6,y_b,'-','LineWidth',1.5,'Color',[110/255 110/255 110/255]) 
plot(mu*p_plax_0_norm_eff_plot_b,y_plax_plot_b,'v','LineWidth',1.5,'Color',[200/255 200/255 200/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[200/255 200/255 200/255]) 
plot(mu*p_plax_20_norm_eff_plot_b,y_plax_plot_b,'v','LineWidth',1.5,'Color',[110/255 110/255 110/255],...
        'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[110/255 110/255 110/255]) 
plot(-mu*p_plax_0_norm_eff_plot_b,y_plax_plot_b,'v','LineWidth',1.5,'Color',[200/255 200/255 200/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[200/255 200/255 200/255]) 
plot(-mu*p_plax_20_norm_eff_plot_b,y_plax_plot_b,'v','LineWidth',1.5,'Color',[110/255 110/255 110/255],...
        'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[110/255 110/255 110/255]) 
plot(sigma_shear_0_b/1e6,y_b,'LineWidth',1.5,'Color',[244/255, 175/255, 65/255]) 
plot((sigma_shear_0_b + sigma_shear_3_b)/1e6,y_b,'r','LineWidth',1.5) 
plot(p_plax_0_shear_plot_b,y_plax_plot_b,'v','LineWidth',1.5,'Color',[244/255, 175/255, 65/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[244/255, 175/255, 65/255]) 
plot(p_plax_20_shear_plot_b,y_plax_plot_b,'v','LineWidth',1.5,'Color','r',...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor','r') 
hold off
xlabel('\rm Shear stresses - production (MPa)')
ylabel('\ity \rm(m)')
if flag_normal == 0
    axis([-45 45 -300 300])
else
    axis([-35 35 -300 300])
end
box on



