function [...
    mu,p_plax_0_norm_eff_plot,p_plax_20_norm_eff_plot,...
    p_plax_0_shear_plot,p_plax_20_shear_plot,...
    sigma_norm_eff_0,sigma_norm_eff_3,...
    sigma_shear_0,sigma_shear_3,...
    y,y_plax_plot] = ...
    disp_fault_num_check_work(flag_inj,flag_normal)
%
% Plots of stresses along an inclined fault for comparison with numerical results.
%
a = 100; % m
alpha = 0.9; % -
b = 200; % m
D_center = 3500; % m
g = 9.81; % m/s^2
mu = 0.6; % -
n_pt_y_2 = 10000;
p_0_center = 35e6; % Pa
phi = 0.15; % -
rho_f = 1020; % kg/m^3
rho_s = 2650; % kg/m^3
y_plot_max =  300;
y_plot_min = -300;
if flag_inj == 0 % production
    p_20_inc = -20e6; % incremental pressure (20 MPa depletion)
    C = -2.3592e+06; % N/m^2;
else % injection
    p_20_inc = 20e6; % incremental pressure (20 MPa overpressure)
    C = 2.3592e+06; % N/m^2;
end
if flag_normal == 0 % reversed fault
    theta = 5*pi/6; % 150 degree (30 degree dip)
    K_eff = 1.2; % -
else % normal fault
    theta = pi/3; % 60 degree
    K_eff = 0.5; % -
end

[G_norm_1,G_norm_2,G_norm_3,...
    G_norm_minus2pi_1,G_norm_minus2pi_2,G_norm_minus2pi_3,...
    ~,~,~,...
    p_0,p_20,...
    sigma_norm_0,sigma_norm_1,sigma_norm_2,sigma_norm_3,...
    sigma_shear_0,sigma_shear_1,sigma_shear_2,sigma_shear_3,y] = ...
    disp_fault_num_check(a,alpha,b,C,D_center,g,K_eff,n_pt_y_2,p_0_center,p_20_inc,phi,...
    rho_f,rho_s,theta,y_plot_max,y_plot_min);

% Read Plaxis results:
col = 6; % effective normal stresses, MPa
[y_plax,p_plax_0_norm_eff,~] = plaxis_results(col,flag_inj,flag_normal);
col = 7; % normal stresses, MPa
[~,p_plax_0_norm,p_plax_20_norm] = plaxis_results(col,flag_inj,flag_normal);
col = 8; % shear stresses, MPa
[~,p_plax_0_shear,p_plax_20_shear] = plaxis_results(col,flag_inj,flag_normal);
p_plax_0_shear = - p_plax_0_shear;
p_plax_20_shear = - p_plax_20_shear;
col = 12; % pressures, MPa
[~,p_plax_0_pres,p_plax_20_pres] = plaxis_results(col,flag_inj,flag_normal);
p_plax_0_pres = - p_plax_0_pres;
p_plax_20_pres = - p_plax_20_pres;

% Apply callibration corrections to ensure that initial pressures are identical at y = 0:
p_plax_norm_corr = -0.9; % MPa
p_plax_norm_eff_corr = -0.9; % MPa
if flag_normal == 0
    p_plax_shear_corr = 1.6; % MPa
else
    p_plax_shear_corr = -0.5; % MPa
end
p_plax_0_shear = p_plax_0_shear + p_plax_shear_corr;
p_plax_20_shear = p_plax_20_shear + p_plax_shear_corr;
p_plax_0_norm = p_plax_0_norm + p_plax_norm_corr;
p_plax_20_norm = p_plax_20_norm + p_plax_norm_corr;
p_plax_0_norm_eff = p_plax_0_norm_eff + p_plax_norm_eff_corr;

% Plot diagnostic results:
figure % G_norm
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(G_norm_1,y,'r','LineWidth',1.5)
hold on
plot(G_norm_2,y,'--b','LineWidth',1.5)
plot(G_norm_3,y,':g','LineWidth',1.5)
hold off
xlabel('\rm Scaled normal stresses (-)')
ylabel('\ity \rm(m)')
axis([-8 8 -300 300])
title('\rm\it G_{norm}')
box on

figure % G_norm - 2 pi delta_Omega
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(G_norm_minus2pi_1,y,'r','LineWidth',1.5)
hold on
plot(G_norm_minus2pi_2,y,'--b','LineWidth',1.5)
plot(G_norm_minus2pi_3,y,':g','LineWidth',1.5)
hold off
xlabel('\rm Scaled normal stresses (-)')
ylabel('\ity \rm(m)')
axis([-8 8 -300 300])
title('\rm\it G_{norm}-\rm2\pi\delta_{\Omega}')
box on

figure % Incremental normal stresses
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(sigma_norm_1/1e6,y,'r','LineWidth',1.5)
hold on
plot(sigma_norm_2/1e6,y,'--b','LineWidth',1.5)
plot(sigma_norm_3/1e6,y,':g','LineWidth',1.5)
plot((p_plax_20_norm-p_plax_0_norm),y_plax,'-.r','LineWidth',1.5)
hold off
xlabel('\rm Incremental normal stresses (MPa)')
ylabel('\ity \rm(m)')
axis([-15 15 -300 300])
title('\rm\it \sigma_{norm,inc}')
box on

figure % Combined (initial plus incremental) normal stresses
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(sigma_norm_0/1e6,y,'k','LineWidth',1.5)
hold on
plot((sigma_norm_0 + sigma_norm_1)/1e6,y,'r','LineWidth',1.5)
plot((sigma_norm_0 + sigma_norm_2)/1e6,y,'--b','LineWidth',1.5)
plot((sigma_norm_0 + sigma_norm_3)/1e6,y,':g','LineWidth',1.5)
plot((p_plax_0_norm),y_plax,'-.r','LineWidth',1.5)
plot((p_plax_20_norm),y_plax,'-.k','LineWidth',1.5)
hold off
xlabel('\rm Combined normal stresses (MPa)')
ylabel('\ity \rm(m)')
if flag_normal == 0
    axis([-100 -70 -300 300])
else
    axis([-70 -40 -300 300])
end
title('\rm\it \sigma_{norm,comb}')
box on

figure % Incremental shear stresses
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(sigma_shear_1/1e6,y,'r','LineWidth',1.5)
hold on
plot(sigma_shear_2/1e6,y,'--b','LineWidth',1.5)
plot(sigma_shear_3/1e6,y,':g','LineWidth',1.5)
plot((p_plax_20_shear-p_plax_0_shear),y_plax,'-.k','LineWidth',1.5)
hold off
xlabel('\rm Incremental shear stresses (MPa)')
ylabel('\ity \rm(m)')
axis([-15 15 -300 300])
title('\rm\it \sigma_{shear,inc}')
box on

figure % Combined (initial plus incremental) shear stresesses
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(sigma_shear_0/1e6,y,'k','LineWidth',1.5)
hold on
plot((sigma_shear_0 + sigma_shear_1)/1e6,y,'r','LineWidth',1.5)
plot((sigma_shear_0 + sigma_shear_2)/1e6,y,'--b','LineWidth',1.5)
plot((sigma_shear_0 + sigma_shear_3)/1e6,y,':g','LineWidth',1.5)
plot((p_plax_0_shear),y_plax,'-.r','LineWidth',1.5)
plot((p_plax_20_shear),y_plax,'-.k','LineWidth',1.5)
hold off
xlabel('\rm Combined shear stresses (MPa)')
ylabel('\ity \rm(m)')
title('\rm\it \sigma_{shear,comb}')
if flag_normal == 0
    axis([-10 10 -300 300])
else
    axis([-30 30 -300 300])
end
box on

if flag_normal == 1
    figure % Pressures
    line([0 0],[-300 300],'Color','k') % vertical line at x = 0
    line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
    line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
    line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
    line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
    line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
    plot(p_0/1e6,y,'b','LineWidth',1.5)
    hold on
    plot(p_20/1e6,y,'g','LineWidth',1.5)
    plot(p_plax_0_pres,y_plax,'--r','LineWidth',1.5)
    plot(p_plax_20_pres,y_plax,'--k','LineWidth',1.5)
    hold off
    xlabel('\rm Pressure (MPa)')
    ylabel('\ity \rm(m)')
    title('\rm\it Pressure to the right of the fault')
    axis([10 40 -300 300])
    legend('\itp\rm = 0 MPa, Matlab','\rm -20 MPa, Matlab','\rm 0 MPa, Plaxis','\rm -20 MPa, Plaxis', 'location','southwest')
    box on
end

% Reduce number of plot points in Plaxis output:
f_red = 20; % reduction factor
n_plax_0_shear = length(p_plax_0_shear); % number of elements
n_seg = floor(n_plax_0_shear/f_red); % number of segments
n_red = floor(n_plax_0_shear/n_seg); % number of elements per segment
sel = linspace(n_red,n_seg*n_red,n_seg); % indices of selected elements
p_plax_0_shear_plot = p_plax_0_shear(sel); % selected elements
p_plax_20_shear_plot = p_plax_20_shear(sel);
y_plax_plot = y_plax(sel);
p_plax_0_norm_plot = p_plax_0_norm(sel);
p_plax_20_norm_plot = p_plax_20_norm(sel);
p_plax_0_norm_eff_plot = p_plax_0_norm_eff(sel);
p_plax_0_pres_plot = p_plax_0_pres(sel);
%p_plax_20_pres_plot = p_plax_20_pres(sel);

figure % combination plot
sigma_norm_eff_0 = sigma_norm_0 + alpha*p_0; % effective initial normal stress
sigma_norm_eff_3 = zeros(n_pt_y_2,1);
for i = 1:n_pt_y_2
    if (-b < y(i) && y(i) < b) % note: effective between -b and b
        sigma_norm_eff_3(i) = sigma_norm_3(i) + alpha*p_20_inc; % effective incremental normal stress
    else
        sigma_norm_eff_3(i) = sigma_norm_3(i);
    end
end
p_plax_20_norm_eff_plot = zeros(1,n_seg);
for i = 1:n_seg
    if (-b < y_plax_plot(i) && y_plax_plot(i) < b) % note: effective between -b and b
        p_plax_20_norm_eff_plot(i) = p_plax_20_norm_plot(i) + alpha*(p_plax_0_pres_plot(i)+p_20_inc/1e6); % effective normal stress
    else
        p_plax_20_norm_eff_plot(i) = p_plax_20_norm_plot(i) + alpha*p_plax_0_pres_plot(i);
    end
end
subplot(1,2,1)
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
hold on
line([-100 100],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-100 100],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-100 100],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-100 100],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-100 100],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(sigma_norm_eff_0/1e6,y,'LineWidth',1.5,'Color',[244/255, 175/255, 65/255]) % initial effective stress
plot(p_plax_0_norm_eff_plot,y_plax_plot,'v','LineWidth',1.5,'Color',[244/255, 175/255, 65/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[244/255, 175/255, 65/255]) % initial effective stress
plot(sigma_norm_3/1e6,y,'g','LineWidth',1.5) % incremental total stress
plot((p_plax_20_norm_plot-p_plax_0_norm_plot),y_plax_plot,'v','LineWidth',1.5,'Color','g',...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor','g')  % incremental total stress
plot(sigma_norm_eff_3/1e6,y,'LineWidth',1.5,'Color','b') % incremental effective stress
plot((p_plax_20_norm_eff_plot-p_plax_0_norm_eff_plot),y_plax_plot,'v','LineWidth',1.5,'Color','b',...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor','b')  % incremental effective stress
plot((sigma_norm_eff_0+sigma_norm_eff_3)/1e6,y,'LineWidth',1.5,'Color','r') % combined (initial + incremental) effective stress
plot(p_plax_20_norm_eff_plot,y_plax_plot,'v','LineWidth',1.5,'Color','r',...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor','r') % combined total stress
hold off
xlabel('\rm Normal stresses (MPa)')
ylabel('\ity \rm(m)')
if flag_inj == 0 && flag_normal == 0
    axis([-80 20 -300 300])
end
if flag_inj == 0 && flag_normal == 1
    axis([-55 15 -300 300])
end
if flag_inj == 1 && flag_normal == 0
    axis([-80 20 -300 300])
end
if flag_inj == 1 && flag_normal == 1
    axis([-45 25 -300 300])
end
box on
subplot(1,2,2)
line([0 0],[-300 300],'LineStyle','-','Color','k','LineWidth',0.5) % vertical line at x = 0
hold on
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(mu*sigma_norm_eff_0/1e6,y,'-','LineWidth',1.5,'Color',[200/255 200/255 200/255]) % left slip boundary
plot(mu*(sigma_norm_eff_0+sigma_norm_eff_3)/1e6,y,'-','LineWidth',1.5,'Color',[110/255 110/255 110/255])
plot(-mu*sigma_norm_eff_0/1e6,y,'-','LineWidth',1.5,'Color',[200/255 200/255 200/255]) % right slip boundary
plot(-mu*(sigma_norm_eff_0+sigma_norm_eff_3)/1e6,y,'-','LineWidth',1.5,'Color',[110/255 110/255 110/255])
plot(mu*p_plax_0_norm_eff_plot,y_plax_plot,'v','LineWidth',1.5,'Color',[200/255 200/255 200/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[200/255 200/255 200/255])
plot(mu*p_plax_20_norm_eff_plot,y_plax_plot,'v','LineWidth',1.5,'Color',[110/255 110/255 110/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[110/255 110/255 110/255])
plot(-mu*p_plax_0_norm_eff_plot,y_plax_plot,'v','LineWidth',1.5,'Color',[200/255 200/255 200/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[200/255 200/255 200/255])
plot(-mu*p_plax_20_norm_eff_plot,y_plax_plot,'v','LineWidth',1.5,'Color',[110/255 110/255 110/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[110/255 110/255 110/255])
plot((sigma_shear_0)/1e6,y,'LineWidth',1.5,'Color',[244/255, 175/255, 65/255])
plot((sigma_shear_0 + sigma_shear_3)/1e6,y,'r','LineWidth',1.5)
plot(p_plax_0_shear_plot,y_plax_plot,'v','LineWidth',1.5,'Color',[244/255, 175/255, 65/255],...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor',[244/255, 175/255, 65/255])
plot(p_plax_20_shear_plot,y_plax_plot,'v','LineWidth',1.5,'Color','r',...
    'MarkerSize',5,'MarkerEdgeColor','none','MarkerFaceColor','r')
hold off
xlabel('\rm Shear stresses (MPa)')
ylabel('\ity \rm(m)')
if flag_normal == 0
    axis([-45 45 -300 300])
else
    axis([-35 35 -300 300])
end
box on

