function disp_fault_plot_Coulomb_as_save(a,b,C,Dy_2,mu,n_pt_y_2,nu,sigma_xx_eff_0,...
    sigma_xy_0,y_1,y_2,y_3,y_4,y_plot_min)
%
% Creates plot of normal, shear and combined stresses along a vertical fault corresponding to
% aseismic slip. 
%

% Plot total and effective horizontal normal stresses for x = 0:
figure
subplot(1,3,1)
y = zeros(n_pt_y_2,1);
sigma_xx_eff_0_plot = zeros(n_pt_y_2,1);
G_xx_plot_limit_0 = zeros(n_pt_y_2,1);
G_xx_eff_plot_limit_0 = zeros(n_pt_y_2,1);
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
    sigma_xx_eff_0_plot(i) = sigma_xx_eff_0; % dimensionless initial effective horizontal
        % stress, -
    if 0 < y(i)
        x = 0;
        x_pp = 0;
    else
        x = 0;
        x_pp = 0-eps;
    end
    G_xx_plot_limit_0(i) = pi/2 *( sign(y(i)+a) + sign(y(i)-a) - sign(y(i)-b) - sign(y(i)+b) );
    % Subtract eigenstress:
    if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
        G_xx_plot_limit_0(i) = G_xx_plot_limit_0(i) - 2*pi;
    end
    % Subtract (negative) pore pressure:
    if (x_pp < 0 && -b < y(i) && y(i) < a) || (0 <= x_pp && -a < y(i) && y(i) < b)
        G_xx_eff_plot_limit_0(i) = G_xx_plot_limit_0(i) + 2*pi*((1-nu)/(1-2*nu));
    end
end
sigma_xx_plot_limit_0 = C * G_xx_plot_limit_0;
sigma_xx_eff_plot_limit_0 = C * G_xx_eff_plot_limit_0;
sigma_xx_eff_res_plot = sigma_xx_eff_0 + sigma_xx_eff_plot_limit_0; % resultant effective
    % stress
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
hold on
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([0 0],[-300 300],'LineStyle','-','Color','k','LineWidth',0.5)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
% Employ cosmetic corrections:
n_corr = round(n_pt_y_2*2/6);
sigma_xx_eff_0_plot(n_corr+1) = sigma_xx_eff_0_plot(n_corr); 
sigma_xx_plot_limit_0(n_corr+1) = sigma_xx_plot_limit_0(n_corr); 
sigma_xx_eff_plot_limit_0(n_corr+1) = sigma_xx_eff_plot_limit_0(n_corr); 
sigma_xx_eff_res_plot(n_corr+1) = sigma_xx_eff_res_plot(n_corr); 
% End of cosmetic corrections
plot(sigma_xx_eff_0_plot/1e6,y,'Color',[244/255, 175/255, 65/255],'LineWidth',1.5) % initial
    % effective stress
plot(sigma_xx_plot_limit_0/1e6,y,'g','LineWidth',1.5) % total stress
plot(sigma_xx_eff_plot_limit_0/1e6,y,'b','LineWidth',1.5) % effective stress
plot(sigma_xx_eff_res_plot/1e6,y,'r','LineWidth',1.5) % resultant effective stress
hold off
axis([-35 15 -300 300])
xlabel('\rma) Horizontal stresses (MN/m)') % 2D units
ylabel('\ity \rm(m)')
box on

% Plot G_xy for x = 0:
subplot(1,3,2)
y = zeros(n_pt_y_2,1);
sigma_xy_0_plot = zeros(n_pt_y_2,1);
%%% G_xy_plot_limit_0 = zeros(n_pt_y_2,1);
G_xy_as_plot = zeros(n_pt_y_2,1);
for i = 1:n_pt_y_2
    y(i) = y_plot_min + (i-1)*Dy_2;
    sigma_xy_0_plot(i) = sigma_xy_0; % dimensionless initial shear stress, -
    G_xy_plot_limit_0 = 0.5 * log( (y(i)-a)^2*(y(i)+a)^2 / ((y(i)-b)^2*(y(i)+b)^2) );
    G_as_xy = 0;
    if y_3 < y(i) && y(i) < y_4 % apply correction to account for aseismic slip
        chi_lo = y_3;
        chi_hi = y_4;
        G_as_xy = Green_vert_g_as_xy(a,b,C,chi_hi,chi_lo,mu,nu,sigma_xy_0,sigma_xx_eff_0,...
            0,y(i));
    end
    G_xy_as_plot(i) = G_xy_plot_limit_0 + G_as_xy; 
end
%%% sigma_xy_plot_limit_0 = C * G_xy_plot_limit_0;
sigma_xy_plot_limit_0 = C * G_xy_as_plot;
sigma_xy_res_plot = sigma_xy_0 + sigma_xy_plot_limit_0; % resultant shear stress
line([0 0],[-300 300],'Color','k') % vertical line at x = 0
hold on
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(sigma_xy_0_plot/1e6,y,'Color',[244/255, 175/255, 65/255],'LineWidth',1.5) % initial shear
    % stress
hold on
plot(sigma_xy_plot_limit_0/1e6,y,'b','LineWidth',1.5) % G_xy at x = 0
plot(sigma_xy_res_plot/1e6,y,'r','LineWidth',1.5) % resultant shear stress
hold off
xlabel('\rmb) Shear stresses (MN/m)') % 2D units
%ylabel('\ity \rm(m)')
%axis([-20 30 -300 300])
box on

% Plot shear stresses with slip boundaries:
subplot(1,3,3)
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
hold on
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([0 0],[-300 300],'LineStyle','-','Color','k','LineWidth',0.5)
line([-50 50],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
plot(mu*sigma_xx_eff_res_plot/1e6,y,'LineWidth',1.5,'Color',[110/255 110/255 110/255])
    % resultant effective stress
plot(-mu*sigma_xx_eff_res_plot/1e6,y,'k','LineWidth',1.5,'Color',[110/255 110/255 110/255])
    % resultant effective stress
plot(sigma_xy_res_plot/1e6,y,'r','LineWidth',1.5) % resultant shear stress
hold off
xlabel('\rmc) Slip boundaries (MN/m)') % 2D units 
%ylabel('\ity \rm(m)')
axis([-20 30 -300 300])
box on

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Plot effects of increasing/decreasing pressures (p_1, p_2 and p_3 MN/m incremental + or -):
figure
subplot(1,2,1) % injection
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
hold on
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([0 0],[-300 300],'LineStyle','-','Color','k','LineWidth',0.5)
line([17.1 17.1],[-300 300],'LineStyle','-','Color',[200/255 200/255 200/255],'LineWidth',1.5)
    % initial static slip boundary
line([15.0 15.0],[-300 300],'LineStyle','-','Color',[244/255, 175/255, 65/255],'LineWidth',1.5)
    % initial shear stress
p_old = 20;
C_old = C;
sigma_xx_eff_0_old = sigma_xx_eff_0;
p_1 =  5; 
p_2 = 20;
p_3 = 35;
% Plot slip boundaries:
%for p = [p_1,p_2,p_3]
for p = [p_2]
    C = p*C_old/p_old;
    sigma_xx_eff_0 = sigma_xx_eff_0_old - p_old + p;
    y = zeros(n_pt_y_2,1);
    sigma_xx_eff_0_plot = zeros(n_pt_y_2,1);
    G_xx_plot_limit_0 = zeros(n_pt_y_2,1);
    G_xx_eff_plot_limit_0 = zeros(n_pt_y_2,1);
    for i = 1:n_pt_y_2
        y(i) = y_plot_min + (i-1)*Dy_2;
        sigma_xx_eff_0_plot(i) = sigma_xx_eff_0; % dimensionless initial effective horizontal
            % stress, -
        if 0 < y(i)
            x = 0;
            x_pp = 0;
        else
            x = 0;
            x_pp = 0-eps;
        end
        G_xx_plot_limit_0(i) = pi/2 *( sign(y(i)+a) + sign(y(i)-a) ...
            - sign(y(i)-b) - sign(y(i)+b) );
        % Subtract eigenstress:
        if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
            G_xx_plot_limit_0(i) = G_xx_plot_limit_0(i) - 2*pi;
        end
        % Subtract (negative) pore pressure:
        if (x_pp < 0 && -b < y(i) && y(i) < a) || (0 <= x_pp && -a < y(i) && y(i) < b)
            G_xx_eff_plot_limit_0(i) = G_xx_plot_limit_0(i) + 2*pi*((1-nu)/(1-2*nu));
        end
    end
    sigma_xx_eff_plot_limit_0 = C * G_xx_eff_plot_limit_0;
    sigma_xx_eff_res_plot = sigma_xx_eff_0 + sigma_xx_eff_plot_limit_0; % resultant effective
        % stress
    % Plot slip boundaries:
    if p == p_1
        plot(mu*sigma_xx_eff_res_plot/1e6,y,'-','LineWidth',1.5,'Color',[150/255 150/255 150/255]) % resultant effective stress
        plot(-mu*sigma_xx_eff_res_plot/1e6,y,'-','LineWidth',1.5,'Color',[150/255 150/255 150/255]) 
    else
        if p == p_2
            plot(mu*sigma_xx_eff_res_plot/1e6,y,'-','LineWidth',1.5,'Color',[110/255 110/255 110/255]) 
            plot(-mu*sigma_xx_eff_res_plot/1e6,y,'-','LineWidth',1.5,'Color',[110/255 110/255 110/255])
        else % p = p_3
            plot(mu*sigma_xx_eff_res_plot/1e6,y,'k','LineWidth',1.5) 
            plot(-mu*sigma_xx_eff_res_plot/1e6,y,'k','LineWidth',1.5) 
        end
    end
end
% Plot shear stresses:
% for p = [p_1,p_2,p_3]
for p = [p_2]
    C = p*C_old/p_old;
    sigma_xy_plot_limit_0 = C * G_xy_plot_limit_0;
    sigma_xy_res_plot = sigma_xy_0 + sigma_xy_plot_limit_0; % resultant shear stress
    if p == p_1
        plot(sigma_xy_res_plot/1e6,y,'b','LineWidth',1.5)
    else
        if p == p_2
            plot(sigma_xy_res_plot/1e6,y,'r','LineWidth',1.5)
        else % p = p_3
            plot(sigma_xy_res_plot/1e6,y,'g','LineWidth',1.5)
        end
    end
end
xlabel('\rma) Stresses (injection) (MN/m)') % 2D units
ylabel('\ity \rm(m)')
axis([0 30 0 300])
box on

%figure
subplot(1,2,2) % production
line([-50 50],[-200 -200],'LineStyle',':','Color','k','LineWidth',1)
hold on
line([-50 50],[-100 -100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[100 100],'LineStyle',':','Color','k','LineWidth',1)
line([-50 50],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([0 0],[-300 300],'LineStyle','-','Color','k','LineWidth',0.5) 
line([17.1 17.1],[-300 300],'LineStyle','-','Color',[200/255 200/255 200/255],'LineWidth',1.5)
    % initial static slip boundary
line([15.0 15.0],[-300 300],'LineStyle','-','Color',[244/255, 175/255, 65/255],'LineWidth',1.5)
    % initial shear stress

% Plot slip boundaries:
% for p = [-p_1,-p_2,-p_3]
for p = [p_2]
    C = p*C_old/p_old;
    sigma_xx_eff_0 = sigma_xx_eff_0_old - 20 + p; % initial effective horizontal stress,
       % N/m
    y = zeros(n_pt_y_2,1);
    sigma_xx_eff_0_plot = zeros(n_pt_y_2,1);
    G_xx_plot_limit_0 = zeros(n_pt_y_2,1);
    G_xx_eff_plot_limit_0 = zeros(n_pt_y_2,1);
    for i = 1:n_pt_y_2
        y(i) = y_plot_min + (i-1)*Dy_2;
        sigma_xx_eff_0_plot(i) = sigma_xx_eff_0; % dimensionless initial effective horizontal
        % stress, -
        if 0 < y(i)
            x = 0;
            x_pp = 0;
        else
            x = 0;
            x_pp = 0-eps;
        end
        G_xx_plot_limit_0(i) = pi/2 *( sign(y(i)+a) + sign(y(i)-a) - sign(y(i)-b) - sign(y(i)+b) );
        % Subtract eigenstress:
        if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
            G_xx_plot_limit_0(i) = G_xx_plot_limit_0(i) - 2*pi;
        end
        % Subtract (negative) pore pressure:
        if (x_pp < 0 && -b < y(i) && y(i) < a) || (0 <= x_pp && -a < y(i) && y(i) < b)
            G_xx_eff_plot_limit_0(i) = G_xx_plot_limit_0(i) + 2*pi*((1-nu)/(1-2*nu));
        end
    end
    sigma_xx_eff_plot_limit_0 = C * G_xx_eff_plot_limit_0;
    sigma_xx_eff_res_plot = sigma_xx_eff_0 + sigma_xx_eff_plot_limit_0; % resultant effective
        % stress
    if p == -p_1
        plot(mu*sigma_xx_eff_res_plot/1e6,y,'-','LineWidth',1.5,'Color',[150/255 150/255 150/255])
        % resultant effective stress
        plot(-mu*sigma_xx_eff_res_plot/1e6,y,'-','LineWidth',1.5,'Color',[150/255 150/255 150/255]) 
    else
        if p == -p_2
            plot(mu*sigma_xx_eff_res_plot/1e6,y,'-','LineWidth',1.5,'Color',[110/255 110/255 110/255]) 
            plot(-mu*sigma_xx_eff_res_plot/1e6,y,'-','LineWidth',1.5,'Color',[110/255 100/255 110/255])
        else % p = -p_3
            plot(mu*sigma_xx_eff_res_plot/1e6,y,'k','LineWidth',1.5) 
            plot(-mu*sigma_xx_eff_res_plot/1e6,y,'k','LineWidth',1.5) 
        end
    end
end
% Plot shear stresses:
% for p = [-p_1,-p_2,-p_3]
for p = [p_2]
    C = p*C_old/p_old;
    sigma_xy_plot_limit_0 = C * G_xy_plot_limit_0;
    sigma_xy_res_plot = sigma_xy_0 + sigma_xy_plot_limit_0; % resultant shear stress
    if p == -p_1
        plot(sigma_xy_res_plot/1e6,y,'b','LineWidth',1.5)
    else
        if p == -p_2
            plot(sigma_xy_res_plot/1e6,y,'r','LineWidth',1.5)
        else % p = -p_3
            plot(sigma_xy_res_plot/1e6,y,'g','LineWidth',1.5)
        end
    end
end

xlabel('\rmb) Stresses (production) (MN/m)')
%ylabel('\ity \rm(m)')
%%%axis([-30 30 -300 300])
axis([0 30 0 300])
box on

