function disp_fault_plot_const_x(a,b,c,d,Dy,flag_inf,n_pt_y,y_plot_min,X_1,X_2,X_3) 
%
% Creates cross-sectional plots of G_x and G_y for constant values of x. 
%

% Plot G_x for constant x values: 
figure
clear x y
y = zeros(n_pt_y,1);
G_x_plot_1 = zeros(n_pt_y,1);
G_x_plot_2 = zeros(n_pt_y,1);
G_x_plot_3 = zeros(n_pt_y,1);
G_x_plot_limit_0 = zeros(n_pt_y,1);
for i = 1:n_pt_y
    y(i) = y_plot_min + (i-1)*Dy;
    x = X_1;
    if flag_inf == 1
        G_x_plot_1(i) = Green_vert_g_x_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_x_plot_1(i) = Green_vert_g_x(a,b,c,d,x,y(i));
    end
    x = X_2;
    if flag_inf == 1
        G_x_plot_2(i) = Green_vert_g_x_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_x_plot_2(i) = Green_vert_g_x(a,b,c,d,x,y(i));
    end
    x = X_3;
    if flag_inf == 1
        G_x_plot_3(i) = Green_vert_g_x_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_x_plot_3(i) = Green_vert_g_x(a,b,c,d,x,y(i));
    end
    G_x_plot_limit_0(i) = log((y(i)-a)^2)*(y(i)-a)/4 ...
                        - log((y(i)+b)^2)*(y(i)+b)/4 ...
                        + log((y(i)+a)^2)*(y(i)+a)/4 ...
                        - log((y(i)-b)^2)*(y(i)-b)/4;  
end
plot(G_x_plot_1,y,'-b','LineWidth',2)
hold on
plot(G_x_plot_2,y,'-r','LineWidth',2)
plot(G_x_plot_3,y,'--g','LineWidth',2)
plot(G_x_plot_limit_0,y,':k','LineWidth',3) % G_x at x = 0
hold off
xlabel('\itG_x \rm(m)')
ylabel('\ity \rm(m)')
title('\rm\it G_x \rm for constant values of \itx')
legend('\itx \rm= X_1 m','\itx \rm= 1e-6 m','\itx \rm= X_3 m','\itx \rm= 0 m','Location','southwest')

% Plot G_y for constant x values: 
figure
clear x y
y = zeros(n_pt_y,1);
G_y_plot_1 = zeros(n_pt_y,1);
G_y_plot_2 = zeros(n_pt_y,1);
G_y_plot_3 = zeros(n_pt_y,1);
G_y_plot_limit_0 = zeros(n_pt_y,1);
for i = 1:n_pt_y
    y(i) = y_plot_min + (i-1)*Dy;
    x = X_1;
    if flag_inf == 1
        G_y_plot_1(i) = Green_vert_g_y_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_y_plot_1(i) = Green_vert_g_y(a,b,c,d,x,y(i));
    end
    x = X_2;
    if flag_inf == 01
        G_y_plot_2(i) = Green_vert_g_y_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_y_plot_2(i) = Green_vert_g_y(a,b,c,d,x,y(i));
    end
    x = X_3;
    if flag_inf == 1
        G_y_plot_3(i) = Green_vert_g_y_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_y_plot_3(i) = Green_vert_g_y(a,b,c,d,x,y(i));
    end
    G_y_plot_limit_0(i) = (pi/4) * (abs(y(i)+a)-abs(y(i)-a)-abs(y(i)-b)+abs(y(i)+b));
end
plot(G_y_plot_1,y,'-b','LineWidth',2)
hold on
plot(G_y_plot_2,y,'-r','LineWidth',2)
plot(G_y_plot_3,y,'--g','LineWidth',2)
plot(G_y_plot_limit_0,y,':k','LineWidth',3) % G_y at x = 0
hold off
xlabel('\itG_y \rm(m)')
ylabel('\ity \rm(m)')
title('\rm\it G_y \rm for constant values of \itx')
legend('\itx \rm= X_1 m','\itx \rm= 1e-6 m','\itx \rm= X_3 m','\itx \rm= 0 m','Location','southeast')

% Plot Delta_G_y for constant x values: 
figure
clear x y
y = zeros(n_pt_y,1);
G_y_plot_1 = zeros(n_pt_y,1);
G_y_plot_3 = zeros(n_pt_y,1);
G_y_plot_limit_0 = zeros(n_pt_y,1);
G_y_plot_limit_min_inf = zeros(n_pt_y,1);
G_y_plot_limit_inf = zeros(n_pt_y,1);
Delta_G_y_plot_limit_inf = zeros(n_pt_y,1);
% Int = 0;
for i = 1:n_pt_y
    y(i) = y_plot_min + (i-1)*Dy;
    x = X_1;
    if flag_inf == 1
        G_y_plot_1(i) = Green_vert_g_y_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_y_plot_1(i) = Green_vert_g_y(a,b,c,d,x,y(i));
    end
    x = X_3;
    if flag_inf == 1
        G_y_plot_3(i) = Green_vert_g_y_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_y_plot_3(i) = Green_vert_g_y(a,b,c,d,x,y(i));
    end
    G_y_plot_limit_0(i) = (pi/4) * (abs(y(i)+a)-abs(y(i)-a)-abs(y(i)-b)+abs(y(i)+b));
    G_y_plot_limit_min_inf(i) = (pi/2) * (abs(y(i)+b)-abs(y(i)-a));
    G_y_plot_limit_inf(i)     = (pi/2) * (abs(y(i)+a)-abs(y(i)-b));
    Delta_G_y_plot_limit_inf(i) = abs(G_y_plot_limit_inf(i) - G_y_plot_limit_min_inf(i));
    Delta_G_y_plot_limit_inf(i) = abs( (G_y_plot_limit_inf(i) - G_y_plot_limit_0(i)) ...
                                      -(G_y_plot_limit_min_inf(i) - G_y_plot_limit_0(i)) );
%     Int = Int + Delta_G_y_plot_limit_inf(i) * Dy;
end
% % Check \int_{-b}^b Delta_G_y dy wich is used to compute the seismic moment:
% check_1 = Int
% check_2 = pi*(b^2 - a^2)
% t = b-a;
% h = a+b;
% check_3 = pi*h*t
plot(G_y_plot_limit_min_inf,y,'b','LineWidth',1.5)
hold on
plot(G_y_plot_1,y,'--b','LineWidth',1.5)
plot(G_y_plot_limit_0,y,'-k','LineWidth',1.5) % G_y at x = 0
plot(G_y_plot_3,y,'--g','LineWidth',1.5)
plot(G_y_plot_limit_inf,y,'g','LineWidth',1.5)
plot(Delta_G_y_plot_limit_inf,y,'r','LineWidth',1.5)
line([-600 600],[-200 -200],'LineStyle',':','Color','k','LineWidth',1) 
line([-600 600],[-100 -100],'LineStyle',':','Color','k','LineWidth',1) 
line([-600 600],[100 100],'LineStyle',':','Color','k','LineWidth',1) 
line([-600 600],[200 200],'LineStyle',':','Color','k','LineWidth',1) 
line([0 0],[-300 300],'LineStyle','-','Color','k')
% Repeat to get colored lines on top of black dotted lines without messing up the legend:
plot(G_y_plot_limit_min_inf,y,'b','LineWidth',1.5)
plot(G_y_plot_1,y,'--b','LineWidth',1.5)
plot(G_y_plot_3,y,'--g','LineWidth',1.5)
plot(G_y_plot_limit_inf,y,'g','LineWidth',1.5)
plot(G_y_plot_limit_0,y,'-k','LineWidth',1.5) % G_y at x = 0
plot(Delta_G_y_plot_limit_inf,y,'r','LineWidth',1.5)
hold off
box on
xlabel('\itG_y \rm(m)')
ylabel('\ity \rm(m)')
%title('\rm\it G_y \rm for constant values of \itx')
legend('\itx \rm=-\infty','\itx \rm= -20 m','\itx \rm= 0 m','\itx \rm= 20 m',...
    '\itx \rm=-\infty','\rm\Delta\itG_y','Location','northwest')

% Plot G_xx for constant x values: 
figure
clear x y
y = zeros(n_pt_y,1);
G_xx_plot_1 = zeros(n_pt_y,1);
G_xx_plot_2 = zeros(n_pt_y,1);
G_xx_plot_3 = zeros(n_pt_y,1);
G_xx_plot_limit_0 = zeros(n_pt_y,1);
for i = 1:n_pt_y
    y(i) = y_plot_min + (i-1)*Dy;
    x = X_1;
    if flag_inf == 1
        G_xx_plot_1(i) = Green_vert_g_xx_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_xx_plot_1(i) = Green_vert_g_xx(a,b,c,d,x,y(i));
    end
    if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
        G_xx_plot_1(i) = G_xx_plot_1(i) - 2*pi;
    end
    x = X_2;
    if flag_inf == 1
        G_xx_plot_2(i) = Green_vert_g_xx_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_xx_plot_2(i) = Green_vert_g_xx(a,b,c,d,x,y(i));
    end
    if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
        G_xx_plot_2(i) = G_xx_plot_2(i) - 2*pi;
    end
    x = X_3;
    if flag_inf == 1
        G_xx_plot_3(i) = Green_vert_g_xx_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_xx_plot_3(i) = Green_vert_g_xx(a,b,c,d,x,y(i));
    end
    if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
        G_xx_plot_3(i) = G_xx_plot_3(i) - 2*pi;
    end
    x = X_2;
    G_xx_plot_limit_0(i) = pi/2 *( sign(y(i)+a) + sign(y(i)-a) - sign(y(i)-b) - sign(y(i)+b) );
    if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
        G_xx_plot_limit_0(i) = G_xx_plot_limit_0(i) - 2*pi;
    end
end
plot(G_xx_plot_1,y,'-b','LineWidth',2)
hold on
plot(G_xx_plot_2,y,'-r','LineWidth',2)
plot(G_xx_plot_3,y,'--g','LineWidth',2)
plot(G_xx_plot_limit_0,y,':k','LineWidth',3) % G_xx at x = 0
hold off
xlabel('\itG_{xx}-\rm2\pi\delta_{\Omega} \rm(-)')
ylabel('\ity \rm(m)')
title('\rm\it G_{xx}-\rm2\pi\delta_{\Omega} \rm for constant values of \itx')
legend('\itx \rm= -20 m','\itx \rm= 1e-6 m','\itx \rm= 20 m','\itx \rm= 0 m','Location','southeast')

% Plot G_yy for constant x values: 
figure
clear x y
y = zeros(n_pt_y,1);
G_yy_plot_1 = zeros(n_pt_y,1);
G_yy_plot_2 = zeros(n_pt_y,1);
G_yy_plot_3 = zeros(n_pt_y,1);
G_yy_plot_limit_0 = zeros(n_pt_y,1);
for i = 1:n_pt_y
    y(i) = y_plot_min + (i-1)*Dy;
    x = X_1;
    if flag_inf == 1
        G_yy_plot_1(i) = Green_vert_g_yy_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_yy_plot_1(i) = Green_vert_g_yy(a,b,c,d,x,y(i));
    end
    if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
        G_yy_plot_1(i) = G_yy_plot_1(i) - 2*pi;
    end
    x = X_2;
    if flag_inf == 1
        G_yy_plot_2(i) = Green_vert_g_yy_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_yy_plot_2(i) = Green_vert_g_yy(a,b,c,d,x,y(i));
    end
    if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
        G_yy_plot_2(i) = G_yy_plot_2(i) - 2*pi;
    end
    x = X_3;
    if flag_inf == 1
        G_yy_plot_3(i) = Green_vert_g_yy_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_yy_plot_3(i) = Green_vert_g_yy(a,b,c,d,x,y(i));
    end
    if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
        G_yy_plot_3(i) = G_yy_plot_3(i) - 2*pi;
    end
    x = X_2;
    G_yy_plot_limit_0(i) = pi/2 *( sign(y(i)+a) - sign(y(i)-a) - sign(y(i)-b) + sign(y(i)+b) );
    if (x < 0 && -b < y(i) && y(i) < a) || (0 <= x && -a < y(i) && y(i) < b)
        G_yy_plot_limit_0(i) = G_yy_plot_limit_0(i) - 2*pi;
    end
end
plot(G_yy_plot_1,y,'-b','LineWidth',2)
hold on
plot(G_yy_plot_2,y,'-r','LineWidth',2)
plot(G_yy_plot_3,y,'--g','LineWidth',2)
plot(G_yy_plot_limit_0,y,':k','LineWidth',3) % G_yy at x = 0
hold off
xlabel('\itG_{yy}-\rm2\pi\delta_{\Omega} \rm(-)')
ylabel('\ity \rm(m)')
title('\rm\it G_{yy}-\rm2\pi\delta_{\Omega} \rm for constant values of \itx')
legend('\itx \rm= -20 m','\itx \rm= 1e-6 m','\itx \rm= 20 m','\itx \rm= 0 m','Location','northeast')

% Plot G_xy for constant x values: 
figure
clear x y
y = zeros(n_pt_y,1);
G_xy_plot_1 = zeros(n_pt_y,1);
G_xy_plot_2 = zeros(n_pt_y,1);
G_xy_plot_3 = zeros(n_pt_y,1);
G_xy_plot_limit_0 = zeros(n_pt_y,1);
for i = 1:n_pt_y
    y(i) = y_plot_min + (i-1)*Dy;
    x = X_1;
    if flag_inf == 1
        G_xy_plot_1(i) = Green_vert_g_xy_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_xy_plot_1(i) = Green_vert_g_xy(a,b,c,d,x,y(i));
    end
    x = X_2;
    if flag_inf == 1
        G_xy_plot_2(i) = Green_vert_g_xy_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_xy_plot_2(i) = Green_vert_g_xy(a,b,c,d,x,y(i));
    end
    x = X_3;
    if flag_inf == 1
        G_xy_plot_3(i) = Green_vert_g_xy_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_xy_plot_3(i) = Green_vert_g_xy(a,b,c,d,x,y(i));
    end
    G_xy_plot_limit_0(i) = log( (y(i)-a)^2*(y(i)+a)^2 / ((y(i)-b)^2*(y(i)+b)^2) );
end
plot(G_xy_plot_1,y,'-b','LineWidth',2)
hold on
plot(G_xy_plot_2,y,'-r','LineWidth',2)
plot(G_xy_plot_3,y,'--g','LineWidth',2)
plot(G_xy_plot_limit_0,y,':k','LineWidth',3) % G_xy at x = 0
hold off
xlabel('\itG_{xy} \rm(-)')
ylabel('\ity \rm(m)')
title('\rm\it G_{xy} \rm for constant values of \itx')
legend('\itx \rm= -20 m','\itx \rm= 1e-6 m','\itx \rm= 20 m','\itx \rm= 0 m','Location','southwest')

% Plot G_xy for constant x values (different values of x):
figure
clear x y
y = zeros(n_pt_y,1);
G_xy_plot_1 = zeros(n_pt_y,1);
G_xy_plot_2 = zeros(n_pt_y,1);
G_xy_plot_3 = zeros(n_pt_y,1);
G_xy_plot_limit_0 = zeros(n_pt_y,1);
for i = 1:n_pt_y
    y(i) = y_plot_min + (i-1)*Dy;
    x = 300;
    if flag_inf == 1
        G_xy_plot_1(i) = Green_vert_g_xy_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_xy_plot_1(i) = Green_vert_g_xy(a,b,c,d,x,y(i));
    end
    x = 30;
    if flag_inf == 1
        G_xy_plot_2(i) = Green_vert_g_xy_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_xy_plot_2(i) = Green_vert_g_xy(a,b,c,d,x,y(i));
    end
    G_xy_plot_limit_0(i) = log( (y(i)-a)^2*(y(i)+a)^2 / ((y(i)-b)^2*(y(i)+b)^2) );
    x = 3;
    if flag_inf == 1
        G_xy_plot_3(i) = Green_vert_g_xy_inf(a,b,x,y(i)); % limit for infinite reservoir
    else
        G_xy_plot_3(i) = Green_vert_g_xy(a,b,c,d,x,y(i));
    end
    G_xy_plot_limit_0(i) = log( (y(i)-a)^2*(y(i)+a)^2 / ((y(i)-b)^2*(y(i)+b)^2) );
end
plot(G_xy_plot_1,y,'k','LineWidth',2)
hold on
plot(G_xy_plot_2,y,'g','LineWidth',2)
plot(G_xy_plot_3,y,'b','LineWidth',2)
plot(G_xy_plot_limit_0,y,'r','LineWidth',2) % G_xy at x = 0
line([-100 100],[-200 -200],'LineStyle',':','Color','k','LineWidth',1) 
line([-100 100],[-100 -100],'LineStyle',':','Color','k','LineWidth',1) 
line([-100 100],[100 100],'LineStyle',':','Color','k','LineWidth',1) 
line([-100 100],[200 200],'LineStyle',':','Color','k','LineWidth',1)
line([0 0],[-300 300],'LineStyle','-','Color','k','LineWidth',0.5)
line([-100 100],[0 0],'LineStyle','-','Color','k','LineWidth',0.5)
% Repeat to get colored lines on top of black dotted lines without messing up the legend:
plot(G_xy_plot_1,y,'k','LineWidth',2)
plot(G_xy_plot_2,y,'g','LineWidth',2)
plot(G_xy_plot_3,y,'b','LineWidth',2)
plot(G_xy_plot_limit_0,y,'r','LineWidth',2) % G_xy at x = 0
hold off
axis([-8 8 -300 300])
box on
xlabel('\itG_{xy} \rm(-)')
ylabel('\ity \rm(m)')
%title('\rm\it G_{xy} \rm for constant values of \itx')
%legend('\itx \rm=\pm 20 m','\itx \rm=\pm 10 m','\itx \rm=\pm 5 m','\itx \rm=\pm 2 m','\itx \rm= 0 m','Location','southwest')
legend('\itx \rm=\pm 300 m', '\itx \rm=\pm 30 m','\itx \rm=\pm 3 m','\itx \rm= 0 m','Location','southwest')
