function disp_fault_plot_images(a,b,c,d,Dx,Dy,flag_inf,flag_vert,n_pt_x,n_pt_y,theta,x_plot_max,...
    x_plot_min,y_plot_max,y_plot_min)
%
% Creates image plots of G_x, G_y, G_xx, G_yy, G_xy, and some more.
%
% Create image plot of G_x:
if flag_vert == 1 % vertical fault; displacements G_x and G_y not available for inclined faults
    clear x y
    G_x_image = zeros(n_pt_y,n_pt_x); % intialization at reservoir pressure
    for i = 1:n_pt_x
        x = x_plot_min + (i-1)*Dx;
        for j = 1:n_pt_y
            y = y_plot_min + (j-1)*Dy;
            if flag_inf == 1
                G_x_image(j,i) = Green_vert_g_x_inf(a,b,x,y); % limit for infinite reservoir
            else
                G_x_image(j,i) = Green_vert_g_x(a,b,c,d,x,y);
            end
        end
    end
    figure
    x = [x_plot_min x_plot_max];
    y = [y_plot_min y_plot_max];
    imagesc(x,-y,G_x_image)
    title('\rm\it G_x \rm(m)')
    plot_layout_vert(a,b,c,d,x_plot_max,x_plot_min,y_plot_max,y_plot_min) % creates contours etc.
    
    % Create image plot of G_y:
    clear x y
    G_y_image = zeros(n_pt_y,n_pt_x); % intialization at reservoir pressure
    for i = 1:n_pt_x
        x = x_plot_min + (i-1)*Dx;
        for j = 1:n_pt_y
            y = y_plot_min + (j-1)*Dy;
            if flag_vert == 1 % vertical fault
                if flag_inf == 1
                    G_y_image(j,i) = Green_vert_g_y_inf(a,b,x,y); % limit for infinite reservoir
                else
                    G_y_image(j,i) = Green_vert_g_y(a,b,c,d,x,y);
                end
            end
        end
    end
    figure
    x = [x_plot_min x_plot_max];
    y = [y_plot_min y_plot_max];
    imagesc(x,-y,G_y_image)
    title('\rm\it G_y \rm(m)')
    plot_layout_vert(a,b,c,d,x_plot_max,x_plot_min,y_plot_max,y_plot_min) % creates contours etc.
end

% Create image plot of G_xx:
clear x y
G_xx_image = zeros(n_pt_y,n_pt_x); % intialization at reservoir pressure
for i = 1:n_pt_x
    x = x_plot_min + (i-1)*Dx;
    for j = 1:n_pt_y
        y = y_plot_min + (j-1)*Dy;
        if flag_vert == 1 % vertical fault
            if flag_inf == 1
                G_xx_image(j,i) = Green_vert_g_xx_inf(a,b,x,y); % limit for infinite reservoir
            else
                G_xx_image(j,i) = Green_vert_g_xx(a,b,c,d,x,y);
            end
            if (-c < x && x < 0 && -b < y && y < a) || (0 <= x && x < d && -a < y && y < b)
                G_xx_image(j,i) = G_xx_image(j,i) - 2*pi;
            end
        else % inclined fault
            if flag_inf == 1
                G_xx_image(j,i) = Green_incl_g_xx_inf(a,b,theta,x,y); % limit for infinite reservoir
            else
                G_xx_image(j,i) = Green_incl_g_xx(a,b,c,d,theta,x,y);
            end
            if (-c < x && x < 0 && -b < y && y < a) || (0 <= x && x < d && -a < y && y < b) %% Has to be adapted for inclined fault!
                G_xx_image(j,i) = G_xx_image(j,i) - 2*pi;
            end
        end
    end
end
figure
x = [x_plot_min x_plot_max];
y = [y_plot_min y_plot_max];
imagesc(x,-y,G_xx_image)
title('\rm\it G_{xx}-\rm2\pi\delta_{\Omega} \rm(-)')
if flag_vert == 1
    plot_layout_vert(a,b,c,d,x_plot_max,x_plot_min,y_plot_max,y_plot_min) % creates contours etc.
else
    plot_layout_incl(a,b,c,d,theta,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
end
% Create image plot of G_yy:
clear x y
G_yy_image = zeros(n_pt_y,n_pt_x); % intialization at reservoir pressure
for i = 1:n_pt_x
    x = x_plot_min + (i-1)*Dx;
    for j = 1:n_pt_y
        y = y_plot_min + (j-1)*Dy;
        if flag_vert == 1 % vertical fault
            if flag_inf == 1
                G_yy_image(j,i) = Green_vert_g_yy_inf(a,b,x,y); % limit for infinite reservoir
            else
                G_yy_image(j,i) = Green_vert_g_yy(a,b,c,d,x,y);
            end
            if (-c < x && x < 0 && -b < y && y < a) || (0 <= x && x < d && -a < y && y < b)
                G_yy_image(j,i) = G_yy_image(j,i) - 2*pi;
            end
        else % inclined fault
            if flag_inf == 1
                G_yy_image(j,i) = Green_incl_g_yy_inf(a,b,theta,x,y); % limit for infinite reservoir
            else
                G_yy_image(j,i) = Green_incl_g_yy(a,b,c,d,theta,x,y);
            end
            if (-c < x && x < 0 && -b < y && y < a) || (0 <= x && x < d && -a < y && y < b) %% Has to be adapted for inclined fault!
                G_yy_image(j,i) = G_yy_image(j,i) - 2*pi;
            end
        end
    end
end
figure
x = [x_plot_min x_plot_max];
y = [y_plot_min y_plot_max];
imagesc(x,-y,G_yy_image)
title('\rm\it G_{yy}-\rm2\pi\delta_{\Omega} \rm(-)')
plot_layout_vert(a,b,c,d,x_plot_max,x_plot_min,y_plot_max,y_plot_min) % creates contours etc.

% Create image plot of G_xy:
clear x y
G_xy_image = zeros(n_pt_y,n_pt_x); % intialization at reservoir pressure
boundary_1 = zeros(n_pt_x,1);
boundary_2 = zeros(n_pt_x,1);
for i = 1:n_pt_x
    x = x_plot_min + (i-1)*Dx;
    for j = 1:n_pt_y
        y = y_plot_min + (j-1)*Dy;
        if flag_vert == 1 % vertical fault
            if flag_inf == 1
                G_xy_image(j,i) = Green_vert_g_xy_inf(a,b,x,y); % limit for infinite reservoir
            else
                G_xy_image(j,i) = Green_vert_g_xy(a,b,c,d,x,y);
            end
        else % inclined fault
            if flag_inf == 1
                G_xy_image(j,i) = Green_incl_g_xy_inf(a,b,theta,x,y); % limit for infinite reservoir
            else
                G_xy_image(j,i) = Green_incl_g_xy(a,b,c,d,theta,x,y);
            end
        end
    end
end
figure
x = [x_plot_min x_plot_max];
y = [y_plot_min y_plot_max];
clims = [-4 4];
% clims = [-10 10];
imagesc(x,-y,G_xy_image,clims)
%    imagesc(x,-y,G_xy_image)
title('\rm\it G_{xy} \rm(-)')
plot_layout_vert(a,b,c,d,x_plot_max,x_plot_min,y_plot_max,y_plot_min) % creates contours etc.
% Plot boundaries between positive and negative shear stresses:
for i = 1:n_pt_x
    x(i) = x_plot_min + (i-1)*Dx;
    boundary_1(i) =  sqrt(2*x(i)^2+b^2+a^2)/sqrt(2);
    boundary_2(i) = -sqrt(2*x(i)^2+b^2+a^2)/sqrt(2);
end
hold on
plot(x,boundary_1,'--k')
plot(x,boundary_2,'--k')
hold off

if flag_vert == 1 % vertical fault
    % Create image plot of (G_xx+G_yy) (average normal stress):
    clear x y
    G_av_norm_image = zeros(n_pt_y,n_pt_x); % intialization at reservoir pressure
    for i = 1:n_pt_x
        x = x_plot_min + (i-1)*Dx;
        for j = 1:n_pt_y
            y = y_plot_min + (j-1)*Dy;
            if flag_inf == 1
                G_av_norm_image(j,i) = ...
                    (Green_vert_g_xx_inf(a,b,x,y) ...
                    + Green_vert_g_yy_inf(a,b,x,y)) / 2; % limit for infinite reservoir
            else
                G_av_norm_image(j,i) = ...
                    (Green_vert_g_xx(a,b,c,d,x,y) + Green_vert_g_yy(a,b,c,d,x,y)) / 2;
            end
            if (-c < x && x < 0 && -b < y && y < a) || (0 <= x && x < d && -a < y && y < b)
                G_av_norm_image(j,i) = G_av_norm_image(j,i) - 2*pi;
            end
        end
    end
    figure
    x = [x_plot_min x_plot_max];
    y = [y_plot_min y_plot_max];
    imagesc(x,-y,G_av_norm_image)
    title('\rm (\itG_{xx}+G_{yy}\rm)/2-\rm2\pi\delta_{\Omega} \rm(-)')
    plot_layout_vert(a,b,c,d,x_plot_max,x_plot_min,y_plot_max,y_plot_min) % creates contours etc.
    
    % Create image plot of largest principal stress:
    clear x y
    G_norm_max_image = zeros(n_pt_y,n_pt_x);
    for i = 1:n_pt_x
        x = x_plot_min + (i-1)*Dx;
        for j = 1:n_pt_y
            y = y_plot_min + (j-1)*Dy;
            if flag_inf == 1
                G_xx = Green_vert_g_xx_inf(a,b,x,y); % limit for infinite reservoir
                G_xy = Green_vert_g_xy_inf(a,b,x,y); % limit for infinite reservoir
                G_yy = Green_vert_g_yy_inf(a,b,x,y); % limit for infinite reservoir
            else
                G_xx = Green_vert_g_xx(a,b,c,d,x,y);
                G_xy = Green_vert_g_xy(a,b,c,d,x,y);
                G_yy = Green_vert_g_yy(a,b,c,d,x,y);
            end
            if (-c < x && x < 0 && -b < y && y < a) || (0 <= x && x < d && -a < y && y < b)
                G_xx = G_xx - 2*pi;
                G_yy = G_yy - 2*pi;
            end
            G_mat = [G_xx G_xy; G_xy G_yy];
            G_norm_max_image(j,i) = max(abs(eig(G_mat)));
        end
    end
    figure
    x = [x_plot_min x_plot_max];
    y = [y_plot_min y_plot_max];
    clims = [0 10];
    imagesc(x,-y,G_norm_max_image,clims)
    title('\rm\it G_{norm,max}-\rm2\pi\delta_{\Omega} \rm(-)')
    plot_layout_vert(a,b,c,d,x_plot_max,x_plot_min,y_plot_max,y_plot_min) % creates contours etc.
    
    % Create image plot of largest shear stress:
    clear x y
    G_shear_max_image = zeros(n_pt_y,n_pt_x);
    for i = 1:n_pt_x
        x = x_plot_min + (i-1)*Dx;
        for j = 1:n_pt_y
            y = y_plot_min + (j-1)*Dy;
            if flag_inf == 1
                G_xx = Green_vert_g_xx_inf(a,b,x,y); % limit for infinite reservoir
                G_xy = Green_vert_g_xy_inf(a,b,x,y); % limit for infinite reservoir
                G_yy = Green_vert_g_yy_inf(a,b,x,y); % limit for infinite reservoir
            else
                G_xx = Green_vert_g_xx(a,b,c,d,x,y);
                G_xy = Green_vert_g_xy(a,b,c,d,x,y);
                G_yy = Green_vert_g_yy(a,b,c,d,x,y);
            end
            if (-c < x && x < 0 && -b < y && y < a) || (0 <= x && x < d && -a < y && y < b)
                G_xx = G_xx - 2*pi;
                G_yy = G_yy - 2*pi;
            end
            G_mat = [G_xx G_xy; G_xy G_yy];
            help = eig(G_mat);
            G_shear_max_image(j,i) = help(1)-help(2);
        end
    end
    figure
    x = [x_plot_min x_plot_max];
    y = [y_plot_min y_plot_max];
    %    clims = [0 10];
    imagesc(x,-y,G_shear_max_image)
    title('\rm\it G_{shear,max} \rm(-)')
    plot_layout_vert(a,b,c,d,x_plot_max,x_plot_min,y_plot_max,y_plot_min) % creates contours etc.
end

