% disp_fault_vert_main
%
% Integrates the Green's functions g_x and g_y to obtain G_x and G_y which represent scaled
% displacements u_x/C_hat and u_y/C_hat respectively and plots the results. The integrations
% are performed analytically over a rectangular reservoir domain crossed by a vertical
% displaced fault.   
%
% Jan Dirk Jansen, TU Delft, November 2018
%

clear vars
close all

% Define reservoir parameters:
alpha = 1; % Biot's coefficient 
Delta_p = 20e6; % pressure drop, Pa
G = 6.5217e9; % shear modulus, Pa
nu = 0.15; % Poisson's ratio, -

% Define numerical values to plot examples:
a = 10; % [m]
b = 20; % [m]
c = 1000; % [m]
d = 2000; % [m]
% c = inf; % [m] Note: only use c = d = inf; just choosing one of them as inf will not work
% d = inf; % [m]

% Define plot locations (vertical and horizontal lines):
% X_1 = -1500; % [m] 
% X_2 = 1e-6; % [m]
% X_3 = 2500; % [m]
% Y_1 = -1500; % [m] 
% Y_2 = 1e-6; % [m]
% Y_3 = 1500; % [m]

X_1 = -40; % [m] 
X_2 = 1e-6; % [m]
X_3 = 40; % [m]
Y_1 = -30; % [m] 
Y_2 = 1e-6; % [m]
Y_3 = 30; % [m]

% X_1 = -1500; % [m] 
% X_2 = 1e-6; % [m]
% X_3 = 2500; % [m]
% Y_1 = -30; % [m] 
% Y_2 = 1e-6; % [m]
% Y_3 = 30; % [m]

% X_1 = -990; % [m] 
% X_2 = 1e-6; % [m]
% X_3 = 1990; % [m]
% Y_1 = -19; % [m] 
% Y_2 = 1e-6; % [m]
% Y_3 = 19; % [m]

% X_1 = -40; % [m] 
% X_2 = 1e-6; % [m]
% X_3 = 40; % [m]
% Y_1 = -15; % [m] 
% Y_2 = 1e-6; % [m]
% Y_3 = 15; % [m]

% Define plot parameters:
% x_plot_min = -1500; % [m]
% x_plot_max =  2500; % [m]
% y_plot_min = -1500; % [m]
% y_plot_max =  1500; % [m]

x_plot_min = -40; % [m]
x_plot_max =  40; % [m]
y_plot_min = -30; % [m]
y_plot_max =  30; % [m]

% x_plot_min = -1500; % [m]
% x_plot_max =  2500; % [m]
% y_plot_min = -30; % [m]
% y_plot_max =  30; % [m]

% x_plot_min = -8; % [m]
% x_plot_max =  8; % [m]
% y_plot_min =   9; % [m]
% y_plot_max =  21; % [m]

n_pt_x = 500; % [-]
n_pt_y = 400; % [-]
Dx = (x_plot_max - x_plot_min)/n_pt_x; % [m]
Dy = (y_plot_max - y_plot_min)/n_pt_y; % [m]

% Perform checks and set flag for infinite reservoir boundaries:
if a < 0 || b < 0 || c < 0 || d < 0
    error('Parameters a, b, c and d should all be positive.');
end
 
if c == inf || d == inf
    if c == inf && d == inf
        flag_inf = 1; % infinite boundaries
    else
        error('Both boundaries should either be finite or infinite.');
    end
else
    flag_inf = 0; % finite boundaries
end

% Compute coefficients:
C_hat = (1-2*nu)*alpha*Delta_p / (2*pi*(1-nu)*G); % coefficient for displacements, - 
C = G*C_hat; % coefficient for stresses, Pa

% Create cross-sectional plots (constant y values):
disp_fault_plot_const_y(a,b,c,d,Dx,flag_inf,n_pt_x,x_plot_min,Y_1,Y_2,Y_3)

% Create cross-sectional plots (constant x values):
disp_fault_plot_const_x(a,b,c,d,Dy,flag_inf,n_pt_y,y_plot_min,X_1,X_2,X_3) 

% Create image plots:
flag_vert = 1;
theta = 0;
disp_fault_plot_images(a,b,c,d,Dx,Dy,flag_inf,flag_vert,n_pt_x,n_pt_y,theta,x_plot_max,...
    x_plot_min,y_plot_max,y_plot_min)