function shear_force(a,alpha,b,C,mu,nu,p_0,p_val,sigma_xx_0,sigma_xy_0)

n_plot = 1000; % number of point in plot, -
p_min = -35e6; % lowest incremental pressure during production, Pa
%p_max =  35e6; % highest incremental pressure during injection, Pa
sigma_xx_eff_0 = sigma_xx_0 + alpha*p_0; % initial effective horizontal stress, Pa

% Production:
Sigma_ex = zeros(n_plot,1);
Sigma_ex_14 = zeros(n_plot,1);
Sigma_ex_23 = zeros(n_plot,1);
p_plot = zeros(n_plot,1);
y_3_el = zeros(n_plot,1);
y_4_el = zeros(n_plot,1);
L_sl_el = zeros(n_plot,1); % slip length, elastic conditions
Delta_p = p_min/n_plot;
p = -Delta_p;
C_old = C;
for i=1:n_plot
    p = p + Delta_p;
    p_plot(i) = p;
    C = -C_old * p / -20e6;
    % Compute intersections of shear stress with right slip boundary:
    help01 =(1-nu)/(1-2*nu);
    sigma_sl_1 = -mu*(sigma_xx_eff_0 + C*2*pi*(help01-1));
    sigma_sl_2 = -mu*(sigma_xx_eff_0 + C*2*pi*(help01-1/2));
    gamma_1 = exp((sigma_sl_1-sigma_xy_0)/(C/2));
    gamma_2 = exp((sigma_sl_2-sigma_xy_0)/(C/2));
    y_3 = real(sqrt( (sqrt(gamma_1)*(b^2-a^2)+gamma_1*b^2-a^2)/(gamma_1-1) ));
    % Note: real part taken to ignore results when y_3 < 0; i.e. after merging of slip patches.
    y_4 = sqrt(-(sqrt(gamma_2)*(b^2-a^2)-gamma_2*b^2+a^2)/(gamma_2-1) );
    y_3_el(i) = y_3;
    y_4_el(i) = y_4;
    L_sl_el(i) = 2 * (y_4-y_3);
    
    % Compute excess shear force:
    Sigma_ex_14(i) = - (C/2) * ( a*log( (2*a)^4 *(y_4-a)^2 / ((a-b)^2*(a+b)^2*(y_4+a)^2) )...
        + b*log( (a-b)^2*(y_4+b)^2 / ((a+b)^2*(y_4-b)^2) )...
        + y_4*log((y_4-b)^2*(y_4+b)^2 / ( (y_4-a)^2*(y_4+a)^2 )) )...
        + (y_4-a)*(sigma_xy_0 - sigma_sl_2);
    Sigma_ex_23(i) = (C/2) * ( a*log( (2*a)^4 *(y_3-a)^2 / ((a-b)^2*(a+b)^2*(y_3+a)^2) )...
        + b*log( (a-b)^2*(y_3+b)^2 / ((a+b)^2*(y_3-b)^2) )...
        + y_3*log((y_3-b)^2*(y_3+b)^2 / ( (y_3-a)^2*(y_3+a)^2 )) )...
        + (a-y_3)*(sigma_xy_0 - sigma_sl_1);
    Sigma_ex(i) = 2 * (Sigma_ex_14(i) + Sigma_ex_23(i));   
end

% Compute numerical derivative d_Sigma_d_p:
d_Sigma_ex_d_p = zeros(n_plot-1,1);
p_plot_dydp = zeros(n_plot-1,1);
for i=1:n_plot-1
    p_plot_dydp(i) = p_plot(i);
    d_Sigma_ex_d_p(i) = (Sigma_ex(i+1) - Sigma_ex(i)) / Delta_p;  
end

% Plot results:
figure
plot(-p_plot/1e6,y_3_el,'-g','LineWidth',1.5);
hold on
plot(-p_plot/1e6,y_4_el,'-k','LineWidth',1.5);
plot(-p_plot/1e6,L_sl_el/2,'-r','LineWidth',1.5);
line([ 0 35],[100 100],'LineStyle',':','Color','k','LineWidth',1.0) % horizontal line at y = 100 m
line([ 0 35],[200 200],'LineStyle',':','Color','k','LineWidth',1.0) % horizontal line at y = 200 m
line([-p_val/1e6 -p_val/1e6],[ 0 300],'LineStyle','--','Color','k','LineWidth',1.0) % vertical line at p = p_val
hold off
xlabel('\it-p \rm(MPa)')
ylabel('\ity \rm(m)')
legend('\ity_3','\ity_4','\it L_{sl} /2','location','southwest')
axis([0 35 0 120])

figure
yyaxis left
plot(-p_plot/1e6,Sigma_ex_23/1e9,'-g','LineWidth',1.5);
hold on
plot(-p_plot/1e6,Sigma_ex_14/1e9,'-k','LineWidth',1.5);
plot(-p_plot/1e6,(Sigma_ex/2)/1e9,'-r','LineWidth',1.5);
hold off
ax1 = gca;
ax1.YColor = 'k';
xlabel('\it-p \rm(MPa)')
ylabel('\it\Sigma_{ex}/2 \rm(GN/m)')
axis([0 35 0 0.3])

yyaxis right
plot(-p_plot_dydp/1e6,d_Sigma_ex_d_p,'-b','LineWidth',1.5);
hold on
line([-p_val/1e6 -p_val/1e6],[-35 0],'LineStyle','--','Color','k','LineWidth',1.0) % vertical line at p = p_val
hold off
ax1 = gca;
ax1.YColor = 'k';
ylabel('\it d\Sigma_{ex}/dp \rm(m)')
legend('\it\Sigma_{ex,3}','\it\Sigma_{ex,4}','\it\Sigma_{ex}/2','\itd\Sigma_{ex}/dp', 'location','southwest')
axis([0 35 -35 0])
