% script file shear_force_as

% Equal to function shear_force.m but includes an attempt to heuristically redistribute excess
% shear to represent aseimic slip.

clear variables
close all

a = 100;
b = 200;
mu = 0.60; % static friction coefficient, -
%mu = 0.53; % static friction coefficient, -
mu_dyn = 0.55; % dynamic friction coefficient, -
n_plot = 500; % number of point in plot, -
nu = 0.15; % Poisson's ratio, -
p_min = -35e6; % lowest incremental depletion, Pa
sigma_xx_eff_0 = -60e6 + 0.9*35e6; % initial effective horizontal stress, Pa
sigma_xy_0 = 15e6; % initial shear stress, Pa
%sigma_xy_0 = 14.7e6; % initial shear stress, Pa
p_val = -30.7756e6; % pressure at which patches merge (@ elastic conditions), Pa

Sigma = zeros(n_plot,1);
Sigma_14 = zeros(n_plot,1);
Sigma_23 = zeros(n_plot,1);
p_plot = zeros(n_plot,1);
y_3_el = zeros(n_plot,1);
y_3_pa = zeros(n_plot,1);
y_3_dyn = zeros(n_plot,1);
y_3_ps = zeros(n_plot,1);
y_4_el = zeros(n_plot,1);
y_4_pa = zeros(n_plot,1);
y_4_dyn = zeros(n_plot,1);
y_4_ps = zeros(n_plot,1);
L_sl_el = zeros(n_plot,1); % slip length, elastic conditions
L_sl_pa = zeros(n_plot,1); % slip length, pseudo-aseismic approach
L_sl_dyn = zeros(n_plot,1); % slip length, dynamic friction
L_sl_ps = zeros(n_plot,1); % slip length, pseudo-seismic approach
Delta_y_sl = zeros(n_plot,1);
Delta_y_sl_dyn = zeros(n_plot,1);
Delta_p = p_min/n_plot;
p = -Delta_p;
for i=1:n_plot
    p = p + Delta_p;
    p_plot(i) = p;
    C = -2.3592e+06 * p / -20e6;
    % Compute intersections of shear stress with right slip boundary:
    help01 =(1-nu)/(1-2*nu);
    sigma_sl_1 = -mu*(sigma_xx_eff_0 + C*2*pi*(help01-1));
    sigma_sl_2 = -mu*(sigma_xx_eff_0 + C*2*pi*(help01-1/2));
    sigma_sl_3 = -mu*sigma_xx_eff_0;
    gamma_1 = exp((sigma_sl_1-sigma_xy_0)/(C/2));
    gamma_2 = exp((sigma_sl_2-sigma_xy_0)/(C/2));
    y_3 = real(sqrt( (sqrt(gamma_1)*(b^2-a^2)+gamma_1*b^2-a^2)/(gamma_1-1) ));
    % Note: real part taken to ignore results when y_3 < 0; i.e. after merging of slip patches.
    y_4 = sqrt(-(sqrt(gamma_2)*(b^2-a^2)-gamma_2*b^2+a^2)/(gamma_2-1) );
    y_3_el(i) = y_3;
    y_4_el(i) = y_4;
    L_sl_el(i) = 2 * (y_4-y_3);
    
    % Compute shear force:
    Sigma_14(i) = - (C/2) * ( a*log( (2*a)^4 *(y_4-a)^2 / ((a-b)^2*(a+b)^2*(y_4+a)^2) )...
        + b*log( (a-b)^2*(y_4+b)^2 / ((a+b)^2*(y_4-b)^2) )...
        + y_4*log((y_4-b)^2*(y_4+b)^2 / ( (y_4-a)^2*(y_4+a)^2 )) )...
        + (y_4-a)*(sigma_xy_0 - sigma_sl_2);
    Sigma_23(i) = (C/2) * ( a*log( (2*a)^4 *(y_3-a)^2 / ((a-b)^2*(a+b)^2*(y_3+a)^2) )...
        + b*log( (a-b)^2*(y_3+b)^2 / ((a+b)^2*(y_3-b)^2) )...
        + y_3*log((y_3-b)^2*(y_3+b)^2 / ( (y_3-a)^2*(y_3+a)^2 )) )...
        + (a-y_3)*(sigma_xy_0 - sigma_sl_1);
    Sigma(i) = 2 * (Sigma_14(i) + Sigma_23(i));
    
    % Pseudo-aseismic slip:
    y_3_pa(i) = y_3 - Sigma_23(i) / sigma_sl_1;
    if isnan(y_3_pa(i)) % cosmetic
        y_3_pa(i) = a;
        y_4_pa(i) = a;
        L_sl_pa(i) = 0;
    else if y_3_pa(i) > 0 % no merging of slip patches yet
            y_4_pa(i) = y_4 + Sigma_14(i) / sigma_sl_2;
            L_sl_pa(i) = 2 * (y_4_pa(i)-y_3_pa(i));
        else % slip patches have merged
            y_3_pa(i) = 0;
            y_4_pa(i) = y_4 + (Sigma_14(i) + (Sigma_23(i) - sigma_sl_1*y_3) ) / sigma_sl_2;
            L_sl_pa(i) = 2 * (y_4_pa(i)-y_3_pa(i));
        end
    end
end    
% Plot results:
plot(-p_plot/1e6,y_3_el,'-g','LineWidth',1.5);
hold on
plot(-p_plot/1e6,y_4_el,'-k','LineWidth',1.5);
plot(-p_plot/1e6,L_sl_el/2,'-r','LineWidth',1.5);
plot(-p_plot/1e6,y_3_pa,'--g','LineWidth',1.5);
plot(-p_plot/1e6,y_4_pa,'--k','LineWidth',1.5);
plot(-p_plot/1e6,L_sl_pa/2,'--r','LineWidth',1.5);
% plot(-p_plot/1e6,y_3_dyn,':g','LineWidth',1.5);
% plot(-p_plot/1e6,y_4_dyn,':k','LineWidth',1.5);
% plot(-p_plot/1e6,L_sl_dyn/2,':r','LineWidth',1.5);
% plot(-p_plot/1e6,y_3_ps,'-.g','LineWidth',1.5);
% plot(-p_plot/1e6,y_4_ps,'-.k','LineWidth',1.5);
% plot(-p_plot/1e6,L_sl_ps/2,'-.r','LineWidth',1.5);
line([ 0 35],[100 100],'LineStyle',':','Color','k','LineWidth',1.0) % horizontal line at y = 100 m
line([ 0 35],[200 200],'LineStyle',':','Color','k','LineWidth',1.0) % horizontal line at y = 200 m
line([-p_val/1e6 -p_val/1e6],[ 0 300],'LineStyle','--','Color','k','LineWidth',1.0) % vertical line at -p = 24 MPa
hold off
xlabel('\it-p \rm(MPa)')
ylabel('\ity \rm(m)')
legend('\ity_{3,el}','\ity_{4,el}','\it L_{sl,el} /2','\ity_{3,pa}','\ity_{4,pa}','\it L_{sl,pa} /2','location','southwest')
axis([0 35 0 120])
%axis([0 35 0 200])

figure
plot(-p_plot/1e6,Sigma_23/1e9,'-g','LineWidth',1.5);
hold on
plot(-p_plot/1e6,Sigma_14/1e9,'-k','LineWidth',1.5);
plot(-p_plot/1e6,(Sigma/2)/1e9,'-r','LineWidth',1.5);
line([-p_val/1e6 -p_val/1e6],[ 0 5],'LineStyle','--','Color','k','LineWidth',1.0) % vertical line at -p = 24 MPa
hold off
xlabel('\it-p \rm(MN/m)')
ylabel('\it\Sigma/2 \rm(GN)')
legend('\it\Sigma_3','\it\Sigma_4','\it \Sigma/2','location','northwest')
axis([0 35 0 0.3])

