% script file shear_force_num

clear variables
close all

a = 100;
b = 200;
mu = 0.60; % static friction coefficient, -
mu_dyn = 0.50; % dynamic friction coefficient, -
n_int_1 = 500; % number of integration points for 0 < y < a, -
n_int_2 = 500; % number of integration points for a < y < b, -
n_plot = 500; % number of point in plot, -
nu = 0.15; % Poisson's ratio, -
p_min = -35e6; % lowest incremental depletion, Pa
sigma_xx_eff_0 = -60e6 + 0.9*35e6; % initial effective horizontal stress, Pa
sigma_xy_0 = 15e6; % initial shear stress, Pa
p_val = -30.7756e6; % pressure at which patches merge (@ elastic conditions), Pa

Sigma   = zeros(n_plot,1);
Sigma_14 = zeros(n_plot,1);
Sigma_23 = zeros(n_plot,1);
p_plot = zeros(n_plot,1);
y_3_el = zeros(n_plot,1);
y_4_el = zeros(n_plot,1);
L_sl_el = zeros(n_plot,1);
Delta_y_sl_dyn = zeros(n_plot,1);
Delta_y_int_1 = a / n_int_1; % step size for numerical integration, m
Delta_y_int_2 = (b-a) / n_int_2; % step size for numerical integration, m
Delta_p = p_min/n_plot;
p = -Delta_p;
for i=1:n_plot
    p = p + Delta_p;
    p_plot(i) = p;
    C = -2.3592e6 * p / -20e6;
    y = - Delta_y_int_1;
    y_3 = a;
    check_y_3 = 1;
    for j=1:n_int_1-1
        y = y + Delta_y_int_1;
        y_int = y + Delta_y_int_1/2; % rectangular integration with mid-point values
        sigma_sl = get_sigma_slip_right(a,b,C,mu,nu,sigma_xx_eff_0,y_int);
        sigma_xy = (C/2) * log( ((y_int-a)^2*(y_int+a)^2) / ((y_int-b)^2*(y_int+b)^2) );
        sigma_xy_comb = sigma_xy_0 + sigma_xy;
        if sigma_xy_comb > sigma_sl
            if check_y_3 == 1
                y_3 = y;
                check_y_3 = 0;
            end
            Sigma_23(i) = Sigma_23(i) + (sigma_xy_comb - sigma_sl) * Delta_y_int_1;
        end
        y_3_el(i) = y_3;
    end
    y = a - Delta_y_int_2;
    y_4 = a;
    check_y_4 = 1;
    for j=1:n_int_2-1
        y = y + Delta_y_int_2;
        y_int = y + Delta_y_int_2/2; % rectangular integration with mid-point values
        sigma_sl = get_sigma_slip_right(a,b,C,mu,nu,sigma_xx_eff_0,y_int);
        sigma_xy = (C/2) * log( ((y_int-a)^2*(y_int+a)^2) / ((y_int-b)^2*(y_int+b)^2) );
        sigma_xy_comb = sigma_xy_0 + sigma_xy;
        if sigma_xy_comb < sigma_sl
            if check_y_4 == 1
                y_4 = y;
                check_y_4 = 0;
            end
        end
        if sigma_xy_comb > sigma_sl
            Sigma_14(i) = Sigma_14(i) + (sigma_xy_comb - sigma_sl) * Delta_y_int_1;
        end
        y_4_el(i) = y_4;
        Sigma(i) = 2 * (Sigma_14(i) + Sigma_23(i));
    end
    L_sl_1 = a-y_3;
    L_sl_2 = y_4-a;
    L_sl_el(i) = 2 * (L_sl_1 + L_sl_2);  
end

% Plot results:
plot(-p_plot/1e6,y_3_el,'-g','LineWidth',1.5);
hold on
plot(-p_plot/1e6,y_4_el,'-k','LineWidth',1.5);
plot(-p_plot/1e6,L_sl_el/2,'-r','LineWidth',1.5);
%plot(-p_plot/1e6,Delta_y_sl,'-b','LineWidth',1.5);
%plot(-p_plot/1e6,Delta_y_sl_dyn,'-c','LineWidth',1.5);
line([ 0 35],[100 100],'LineStyle',':','Color','k','LineWidth',1.0) % horizontal line at y = 100 m
line([ 0 35],[200 200],'LineStyle',':','Color','k','LineWidth',1.0) % horizontal line at y = 200 m
line([-p_val/1e6 -p_val/1e6],[ 0 300],'LineStyle','--','Color','k','LineWidth',1.0) % vertical line at -p = 24 MPa
hold off
xlabel('\it-p \rm(MPa)')
ylabel('\ity \rm(m)')
legend('\ity_3','\ity_4','\it L_{sl,el} /2','location','southwest')
axis([0 35 0 120])

figure
plot(-p_plot/1e6,Sigma_23/1e9,'-g','LineWidth',1.5);
hold on
plot(-p_plot/1e6,Sigma_14/1e9,'-k','LineWidth',1.5);
plot(-p_plot/1e6,(Sigma/2)/1e9,'-r','LineWidth',1.5);
line([-p_val/1e6 -p_val/1e6],[ 0 5],'LineStyle','--','Color','k','LineWidth',1.0) % vertical line at -p = 24 MPa
hold off
xlabel('\it-p \rm(MPa)')
ylabel('\it\Sigma/2 \rm(GN)')
axis([0 35 0 0.3])

