% Checks manual simplification of definite integrals of Green's functions.

% 1x) Square, g_x:
% Compute the integrals symbolically:
syms e p q r s x y zeta xi
gx = (x-zeta) / (2*( (x-zeta)^2 + (y-xi)^2 ) ); % Green's function g_x, [1/m]

g1x1 = int(gx,zeta);
g2x1 = simplify(subs(g1x1,zeta,q) - subs(g1x1,zeta,p),'Steps',10);
g3x1 = int(g2x1,xi);
g4x1 = simplify(subs(g3x1,xi,s) - subs(g3x1,xi,r),'Steps',10);

% Output (from screen):
g4x1a = ...
  (q*(atan((r - y)/(q - x)) - atan((s - y)/(q - x))))/2 ...
- (p*(atan((r - y)/(p - x)) - atan((s - y)/(p - x))))/2 ...
- (r*log(p^2 - 2*p*x + r^2 - 2*r*y + x^2 + y^2))/4 ...
+ (r*log(q^2 - 2*q*x + r^2 - 2*r*y + x^2 + y^2))/4 ...
+ (s*log(p^2 - 2*p*x + s^2 - 2*s*y + x^2 + y^2))/4 ...
- (s*log(q^2 - 2*q*x + s^2 - 2*s*y + x^2 + y^2))/4 ...
+ (y*log(p^2 - 2*p*x + r^2 - 2*r*y + x^2 + y^2))/4 ...
- (y*log(p^2 - 2*p*x + s^2 - 2*s*y + x^2 + y^2))/4 ...
- (y*log(q^2 - 2*q*x + r^2 - 2*r*y + x^2 + y^2))/4 ...
+ (y*log(q^2 - 2*q*x + s^2 - 2*s*y + x^2 + y^2))/4 ...
+ (x*(atan((r - y)/(p - x)) - atan((s - y)/(p - x)) ...
- atan((r - y)/(q - x)) + atan((s - y)/(q - x))))/2;

help01 = g4x1 - g4x1a;
check01 = simplify(help01,'Steps',10)

g4x1b = ... % manually simplified screen output
+ (  log((x-q)^2+(y-s)^2) - log((x-p)^2+(y-s)^2)  ) * (y-s)/4 ...
- (  log((x-q)^2+(y-r)^2) - log((x-p)^2+(y-r)^2)  ) * (y-r)/4 ...
+ ( atan((y-s)/(x-q)) - atan((y-r)/(x-q)) ) * (x-q)/2 ...
- ( atan((y-s)/(x-p)) - atan((y-r)/(x-p)) ) * (x-p)/2;

help02 = g4x1 - g4x1b;
check02 = simplify(help02,'Steps',10)

% 1y) Square, g_y:
% Compute the integrals symbolically:
syms e p q r s x y zeta xi
gy = (y-xi) / (2*( (x-zeta)^2 + (y-xi)^2 ) ); % Green's function g_x, [1/m]

g1y1 = int(gy,zeta);
g2y1 = simplify(subs(g1y1,zeta,q) - subs(g1y1,zeta,p),'Steps',10);
g3y1 = int(g2y1,xi);
g4y1 = simplify(subs(g3y1,xi,s) - subs(g3y1,xi,r),'Steps',10);

% Output (from screen):
g4y1a = ...
  (s/2 - y/2)*(atan(p/(s - y) - x/(s - y)) - atan(q/(s - y) - x/(s - y))) ...
- (r/2 - y/2)*(atan(p/(r - y) - x/(r - y)) - atan(q/(r - y) - x/(r - y))) ...
- (p*log((r - y)^2 - 2*p*x + p^2 + x^2))/4 ...
+ (p*log((s - y)^2 - 2*p*x + p^2 + x^2))/4 ...
+ (q*log((r - y)^2 - 2*q*x + q^2 + x^2))/4 ...
- (q*log((s - y)^2 - 2*q*x + q^2 + x^2))/4 ...
+ (x*log((r - y)^2 - 2*p*x + p^2 + x^2))/4 ...
- (x*log((s - y)^2 - 2*p*x + p^2 + x^2))/4 ...
- (x*log((r - y)^2 - 2*q*x + q^2 + x^2))/4 ...
+ (x*log((s - y)^2 - 2*q*x + q^2 + x^2))/4;

help11 = g4y1 - g4y1a;
check11 = simplify(help11,'Steps',10)

g4y1b = ... % manually simplified screen output
+ (  log((x-q)^2+(y-s)^2) - log((x-q)^2+(y-r)^2)) * (x-q)/4 ...
- (  log((x-p)^2+(y-s)^2) - log((x-p)^2+(y-r)^2)) * (x-p)/4 ...
+ ( atan((x-q)/(y-s)) - atan((x-p)/(y-s)) ) * (y-s)/2 ...
- ( atan((x-q)/(y-r)) - atan((x-p)/(y-r)) ) * (y-r)/2;
% % + (atan((p-x)/(s-y)) - atan((q-x)/(s-y))) * (s-y)/2 ...
% % - (atan((p-x)/(r-y)) - atan((q-x)/(r-y))) * (r-y)/2;

help12 = g4y1 - g4y1b;
check12 = simplify(help12,'Steps',10)
stop
% 2x) Triangle g_x (right of fault):
g1x3 = int(gx,zeta);
g2x3 = simplify(subs(g1x3,zeta,q) - subs(g1x3,zeta,(e*xi)),'Steps',10);
% Manually simplify the expression; necessary because otherwise the next integration step
% cannot be performed (on my computer):
g2x3_simp = log((x - e*xi)^2 + (y - xi)^2)/4 - log((x - q)^2 + (y - xi)^2)/4;

help03 = g2x3 - g2x3_simp;
simplify(help03,'Steps',10)

g2x3_simp_part_1 = log((x - e*xi)^2 + (y - xi)^2)/4;
g2x3_simp_part_2 = - log((x - q)^2 + (y - xi)^2)/4;
g3x3_part_1 = int(g2x3_simp_part_1,xi);
g3x3_part_2 = int(g2x3_simp_part_2,xi);
g3x3 = g3x3_part_1 + g3x3_part_2;
g4x3 = simplify(subs(g3x3,xi,s) - subs(g3x3,xi,r),'Steps',10);

% Output (from screen):
g4x3a = ...
    (q/2 - x/2)*(atan((r - y)/(q - x)) - atan((s - y)/(q - x))) ...
    - (r*log((r - y)^2 + (x - e*r)^2))/4 ...
    + (s*log((s - y)^2 + (x - e*s)^2))/4 ...
    + (log((q - x)^2 + (r - y)^2)*(r - y))/4 ...
    - (log((q - x)^2 + (s - y)^2)*(s - y))/4 ...
    - ((x - e*y)*(atan((r*e^2 - x*e + r - y)/(x - e*y)) ...
    - atan((s*e^2 - x*e + s - y)/(x - e*y))))/(2*(e^2 + 1)) ...
    + (log(e^2*r^2 - 2*e*r*x + r^2 - 2*r*y + x^2 + y^2)*(2*y + 2*e*x))/(8*(e^2 + 1)) ...
    - (log(e^2*s^2 - 2*e*s*x + s^2 - 2*s*y + x^2 + y^2)*(2*y + 2*e*x))/(8*(e^2 + 1));
 
help04 = g4x3 - g4x3a;
simplify(help04,'Steps',10)

g4x3b = ... % manually simplified screen output (not finished yet)
    + log((x-q)^2 + (y-s)^2)   * (y-s)/4 ...
    - log((x-q)^2 + (y-r)^2)   * (y-r)/4 ...
    + log((x-e*s)^2 + (y-s)^2) * s/4 ...
    - log((x-e*r)^2 + (y-r)^2) * r/4 ...
    + log((x-e*r)^2 + (y-r)^2) * (y + e*x)/(4*(e^2 + 1)) ...
    - log((x-e*s)^2 + (y-s)^2) * (y + e*x)/(4*(e^2 + 1)) ...
    - ((x - e*y)*(atan((r*e^2 - x*e + r - y)/(x - e*y)) ...
    + (q/2 - x/2)*(atan((r - y)/(q - x)) - atan((s - y)/(q - x))) ...
    - atan((s*e^2 - x*e + s - y)/(x - e*y))))/(2*(e^2 + 1));

% % g4x1b = ... % reproduced here for comparison
% % + (  log((x-q)^2+(y-s)^2) - log((x-p)^2+(y-s)^2)  ) * (y-s)/4 ...
% % - (  log((x-q)^2+(y-r)^2) - log((x-p)^2+(y-r)^2)  ) * (y-r)/4 ...
% % + ( atan((y - s)/(x - q)) - atan((y - r)/(x - q)) ) * (x-q)/2 ...
% % - ( atan((y - s)/(x - p)) - atan((y - r)/(x - p)) ) * (x-p)/2;

help05 = g4x3 - g4x3b;
simplify(help02,'Steps',10)
