% First checks manually simplified output. Then computes and checks limits of definite
% integrals of Green's functions for an infinite reservoir. 

clear vars
close all

% 1x) Square, g_y:
syms a b c d x y zeta xi 
gy = (y-xi) / (2*( (x-zeta)^2 + (y-xi)^2 ) ); % Green's function g_y, [1/m]

% Part 1: simplify expressions:

% % Part I (rectangular part, left of fault):
% g1y1 = int(gy,zeta);
% g2y1 = simplify(subs(g1y1,zeta,0) - subs(g1y1,zeta,-c),'Steps',10);
% g3y1 = int(g2y1,xi);
% g4y1 = simplify(subs(g3y1,xi,a) - subs(g3y1,xi,-b),'Steps',10);

% Part IV (rectangular part, right of fault):
g1y4 = int(gy,zeta);
g2y4 = simplify(subs(g1y4,zeta,d) - subs(g1y4,zeta,0),'Steps',10);
g3y4 = int(g2y4,xi);
g4y4 = simplify(subs(g3y4,xi,b) - subs(g3y4,xi,-a),'Steps',10);

% Original symbolic output (g4y1 and g4y4 as taken from Matlab command window):
% g4y1a = ...
%  (x*log(2*c*x + (b + y)^2 + c^2 + x^2))/4 ...
%  - (x*log((b + y)^2 + x^2))/4 ...
%  - (c*log(2*c*x + c^2 + x^2 + (a - y)^2))/4 ...
%  - (x*log(2*c*x + c^2 + x^2 + (a - y)^2))/4 ...
%  + (x*log(x^2 + (a - y)^2))/4 ...
%  + (atan(c/(b + y) + x/(b + y)) ...
%  - atan(x/(b + y)))*(b/2 + y/2) ...
%  + (atan(x/(a - y)) - atan(c/(a - y) ...
%  + x/(a - y)))*(a/2 - y/2) ...
%  + (c*log(2*c*x + (b + y)^2 + c^2 + x^2))/4;
  
g4y4a =...
(x*log((a + y)^2 + x^2))/4 ...
- (x*log((a + y)^2 - 2*d*x + d^2 + x^2))/4 ...
+ (atan(d/(a + y) - x/(a + y)) ...
+ atan(x/(a + y)))*(a/2 + y/2) ...
- (atan(x/(b - y)) + atan(d/(b - y) ...
- x/(b - y)))*(b/2 - y/2) ...
- (d*log(d^2 - 2*d*x + x^2 + (b - y)^2))/4 ...
+ (x*log(d^2 - 2*d*x + x^2 + (b - y)^2))/4 ...
- (x*log(x^2 + (b - y)^2))/4 ...
+ (d*log((a + y)^2 - 2*d*x + d^2 + x^2))/4;

% Manually simplified symbolic output:
g4y4b = ...
  (log((x-d)^2 + (y-b)^2) - log((x-d)^2 + (y+a)^2) ) * (x-d)/4 ...
- (log(    x^2 + (y-b)^2) - log(    x^2 + (y+a)^2) ) *     x/4 ...
- (atan(    x/(y-b)) - atan((x-d)/(y-b))) * (y-b)/2 ...
+ (atan(    x/(y+a)) - atan((x-d)/(y+a))) * (y+a)/2;

% Same but with use of atan 2. Note: sometimes fails!!!
g4y4c = ...
  (log((x-d)^2 + (y-b)^2) - log((x-d)^2 + (y+a)^2) ) * (x-d)/4 ...
- (log(    x^2 + (y-b)^2) - log(    x^2 + (y+a)^2) ) *     x/4 ...
- (atan2(    x,(y-b)) - atan2((x-d),(y-b))) * (y-b)/2 ...
+ (atan2(    x,(y+a)) - atan2((x-d),(y+a))) * (y+a)/2;

% Further manually simplified symbolic output (Note: numerical implementation requires use of
% atan2 function): 
g4y4d = ...
  (log( ((x-d)^2 + (y-b)^2) / ((x-d)^2 + (y+a)^2)) ) * (x-d)/4 ...
- (log( (    x^2 + (y-b)^2) / (    x^2 + (y+a)^2)) ) *     x/4 ...
 + atan( -d*(y-b) / ((y-b)^2 + (x-d)*x) ) * (y-b)/2 ...
 - atan( -d*(y+a) / ((y+a)^2 + (x-d)*x) ) * (y+a)/2; 

% Further manually simplified symbolic output with use of atan2 function:
g4y4e = ...
  log(((x-d)^2 + (y-b)^2) / ((x-d)^2 + (y+a)^2) ) * (x-d)/4 ...
- log((    x^2 + (y-b)^2) / (    x^2 + (y+a)^2) ) *     x/4 ...
+ atan2( -d*(y-b) , ((y-b)^2 + (x-d)*x) ) * (y-b)/2 ...
- atan2( -d*(y+a) , ((y+a)^2 + (x-d)*x) ) * (y+a)/2; 

% Part 2: determine limits for d to inf:

% Split g4y4a:
g4y4a_1 = (x*log((a + y)^2 + x^2))/4;
g4y4a_2 = - (x*log((a + y)^2 - 2*d*x + d^2 + x^2))/4;
g4y4a_3 =   (atan(d/(a + y) - x/(a + y))+ atan(x/(a + y)))*(a/2 + y/2);
g4y4a_4 = - (atan(x/(b - y)) + atan(d/(b - y) - x/(b - y)))*(b/2 - y/2);
g4y4a_5 = - (d*log(d^2 - 2*d*x + x^2 + (b - y)^2))/4;
g4y4a_6 =   (x*log(d^2 - 2*d*x + x^2 + (b - y)^2))/4;
g4y4a_7 = - (x*log(x^2 + (b - y)^2))/4;
g4y4a_8 =   (d*log((a + y)^2 - 2*d*x + d^2 + x^2))/4;

% Take limit for d to inf:
g11y4a_1_inf = simplify(limit(g4y4a_1,d,inf),'Steps',10);
g11y4a_2_inf = simplify(limit(g4y4a_2,d,inf),'Steps',10);
g11y4a_3_inf = simplify(limit(g4y4a_3,d,inf),'Steps',10);
g11y4a_4_inf = simplify(limit(g4y4a_4,d,inf),'Steps',10);
g11y4a_5_inf = simplify(limit(g4y4a_5,d,inf),'Steps',10);
g11y4a_6_inf = simplify(limit(g4y4a_6,d,inf),'Steps',10);
g11y4a_7_inf = simplify(limit(g4y4a_7,d,inf),'Steps',10);
g11y4a_8_inf = simplify(limit(g4y4a_8,d,inf),'Steps',10);

% Recombine:
g11y4a_inf = simplify(g11y4a_1_inf + g11y4a_2_inf + g11y4a_3_inf + g11y4a_4_inf ...
    + g11y4a_5_inf + g11y4a_6_inf + g11y4a_7_inf + g11y4a_8_inf,'Steps',10)

% Split g4y4b:
g4y4b_1 =   (log((x-d)^2 + (y-b)^2) - log((x-d)^2 + (y+a)^2) ) * (x-d)/4;
g4y4b_2 = - (log(    x^2 + (y-b)^2) - log(    x^2 + (y+a)^2) ) *     x/4;
g4y4b_3 = - (atan(    x/(y-b)) - atan((x-d)/(y-b))) * (y-b)/2;
g4y4b_4 = + (atan(    x/(y+a)) - atan((x-d)/(y+a))) * (y+a)/2; 

% Take limit for d to inf:
g11y4b_1_inf = simplify(limit(g4y4b_1,d,inf),'Steps',10);
g11y4b_2_inf = simplify(limit(g4y4b_2,d,inf),'Steps',10);
g11y4b_3_inf = simplify(limit(g4y4b_3,d,inf),'Steps',10);
g11y4b_4_inf = simplify(limit(g4y4b_4,d,inf),'Steps',10);

% Recombine:
g11y4b_inf = simplify(g11y4b_1_inf + g11y4b_2_inf + g11y4b_3_inf + g11y4b_4_inf,'Steps',10)

% Split g4y4d:
g4y4d_1 =   (log( ((x-d)^2 + (y-b)^2) / ((x-d)^2 + (y+a)^2)) ) * (x-d)/4;
g4y4d_2 = - (log( (    x^2 + (y-b)^2) / (    x^2 + (y+a)^2)) ) *     x/4;
g4y4d_3 =   atan( -d*(y-b) / ((y-b)^2 + (x-d)*x) ) * (y-b)/2;
g4y4d_4 = - atan( -d*(y+a) / ((y+a)^2 + (x-d)*x) ) * (y+a)/2; 

% Take limit for d to inf:
g11y4d_1_inf = simplify(limit(g4y4d_1,d,inf),'Steps',10);
g11y4d_2_inf = simplify(limit(g4y4d_2,d,inf),'Steps',10);
g11y4d_3_inf = simplify(limit(g4y4d_3,d,inf),'Steps',10);
g11y4d_4_inf = simplify(limit(g4y4d_4,d,inf),'Steps',10);

% Recombine:
g11y4d_inf = simplify(g11y4d_1_inf + g11y4d_2_inf + g11y4d_3_inf + g11y4d_4_inf,'Steps',10)

% Split g4y4e:
g4y4e_1 =   (log( ((x-d)^2 + (y-b)^2) / ((x-d)^2 + (y+a)^2)) ) * (x-d)/4;
g4y4e_2 = - (log( (    x^2 + (y-b)^2) / (    x^2 + (y+a)^2)) ) *     x/4;
g4y4e_3 =   atan2( -d*(y-b) , ((y-b)^2 + (x-d)*x) ) * (y-b)/2;
g4y4e_4 = - atan2( -d*(y+a) , ((y+a)^2 + (x-d)*x) ) * (y+a)/2; 

% Take limit for d to inf: (Fails! Results in complex (real/imaginary) expressions.)
g11y4e_1_inf = simplify(limit(g4y4e_1,d,inf),'Steps',10);
g11y4e_2_inf = simplify(limit(g4y4e_2,d,inf),'Steps',10);
g11y4e_3_inf = simplify(limit(g4y4e_3,d,inf),'Steps',10);
g11y4e_4_inf = simplify(limit(g4y4e_4,d,inf),'Steps',10);

% Recombine:
g11y4e_inf = simplify(g11y4e_1_inf + g11y4e_2_inf + g11y4e_3_inf + g11y4e_4_inf,'Steps',10)

% Original symbolic output (g11y4d_inf as taken from Matlab command window):
g11y4f_inf = ...
      (atan((b - y)/x)*(b - y))/2 ...
    - (x*log((x^2 + (b - y)^2)/((a + y)^2 + x^2)))/4 ...
    - (atan((a + y)/x)*(a + y))/2;

% g11y4f_inf with use of atan2:
g11y4g_inf = ...
      atan2((b - y),x) * (b - y)/2 ...
    - (x*log((x^2 + (b - y)^2)/((a + y)^2 + x^2)))/4 ...
    - atan2((a + y),x) * (a + y)/2;

% Manually simplified symbolic output with use of atan2:
g11y4h_inf = ...
    - log( (x^2 + (y-b)^2) / ((y+a)^2 + x^2) ) * x/4 ...
    + atan2((b-y),x) * (b-y)/2 ...
    - atan2((a+y),x) * (a+y)/2;

% Part 3: determine limits for x and d to inf:

% Take limit for x to d:
g21y4d_1_inf = simplify(limit(g4y4d_1,x,d),'Steps',10);
g21y4d_2_inf = simplify(limit(g4y4d_2,x,d),'Steps',10);
g21y4d_3_inf = simplify(limit(g4y4d_3,x,d),'Steps',10);
g21y4d_4_inf = simplify(limit(g4y4d_4,x,d),'Steps',10);

% Take limit for d to inf:
g22y4d_1_inf = simplify(limit(g21y4d_1_inf,d,inf),'Steps',10);
g22y4d_2_inf = simplify(limit(g21y4d_2_inf,d,inf),'Steps',10);
g22y4d_3_inf = simplify(limit(g21y4d_3_inf,d,inf),'Steps',10);
g22y4d_4_inf = simplify(limit(g21y4d_4_inf,d,inf),'Steps',10);

% Recombine:
g22y4d_inf = simplify(g22y4d_1_inf + g22y4d_2_inf + g22y4d_3_inf + g22y4d_4_inf,'Steps',10)

stop
% Original symbolic output (g22y4d_inf as taken from Matlab command window):
g22y4d_inf = ...
    - (pi*signIm(1i/(b - y))*(b - y))/4 + (pi*signIm(1i/(a + y))*(a + y))/4 

% Manually simplified symbolic output with use of atan2:
g22y4d_inf = ...
       ( sign(a+y)*(a+y) + sign(y-b)*(y-b) ) * pi/4

% Part 4: Substitute numerical values and perform checks:

A = 10; % [m]
B = 20; % [m]
D = 200; % [m]
X = 100; % [m]
Y = 30; % [m]

g5y4 = subs(g4y4,a,A);
g6y4 = subs(g5y4,b,B);
g7y4 = subs(g6y4,d,D);
g8y4 = subs(g7y4,x,X);
g9y4 = subs(g8y4,y,Y);

g5y4a = subs(g4y4a,a,A);
g6y4a = subs(g5y4a,b,B);
g7y4a = subs(g6y4a,d,D);
g8y4a = subs(g7y4a,x,X);
g9y4a = subs(g8y4a,y,Y);

g5y4b = subs(g4y4b,a,A);
g6y4b = subs(g5y4b,b,B);
g7y4b = subs(g6y4b,d,D);
g8y4b = subs(g7y4b,x,X);
g9y4b = subs(g8y4b,y,Y);

g5y4c = subs(g4y4c,a,A);
g6y4c = subs(g5y4c,b,B);
g7y4c = subs(g6y4c,d,D);
g8y4c = subs(g7y4c,x,X);
g9y4c = subs(g8y4c,y,Y);

g5y4d = subs(g4y4d,a,A);
g6y4d = subs(g5y4d,b,B);
g7y4d = subs(g6y4d,d,D);
g8y4d = subs(g7y4d,x,X);
g9y4d = subs(g8y4d,y,Y);

g5y4e = subs(g4y4e,a,A);
g6y4e = subs(g5y4e,b,B);
g7y4e = subs(g6y4e,d,D);
g8y4e = subs(g7y4e,x,X);
g9y4e = subs(g8y4e,y,Y);

g12y4a_inf = subs(g11y4a_inf,a,A);
g13y4a_inf = subs(g12y4a_inf,b,B);
g14y4a_inf = subs(g13y4a_inf,d,D);
g15y4a_inf = subs(g14y4a_inf,x,X);
g16y4a_inf = subs(g15y4a_inf,y,Y);

g12y4b_inf = subs(g11y4b_inf,a,A);
g13y4b_inf = subs(g12y4b_inf,b,B);
g14y4b_inf = subs(g13y4b_inf,d,D);
g15y4b_inf = subs(g14y4b_inf,x,X);
g16y4b_inf = subs(g15y4b_inf,y,Y);

g12y4c_inf = subs(g11y4c_inf,a,A);
g13y4c_inf = subs(g12y4c_inf,b,B);
g14y4c_inf = subs(g13y4c_inf,d,D);
g15y4c_inf = subs(g14y4c_inf,x,X);
g16y4c_inf = subs(g15y4c_inf,y,Y);

g12y4d_inf = subs(g11y4d_inf,a,A);
g13y4d_inf = subs(g12y4d_inf,b,B);
g14y4d_inf = subs(g13y4d_inf,d,D);
g15y4d_inf = subs(g14y4d_inf,x,X);
g16y4d_inf = subs(g15y4d_inf,y,Y);

g12y4e_inf = subs(g11y4e_inf,a,A);
g13y4e_inf = subs(g12y4e_inf,b,B);
g14y4e_inf = subs(g13y4e_inf,d,D);
g15y4e_inf = subs(g14y4e_inf,x,X);
g16y4e_inf = subs(g15y4e_inf,y,Y);

g12y4f_inf = subs(g11y4f_inf,a,A);
g13y4f_inf = subs(g12y4f_inf,b,B);
g14y4f_inf = subs(g13y4f_inf,d,D);
g15y4f_inf = subs(g14y4f_inf,x,X);
g16y4f_inf = subs(g15y4f_inf,y,Y);

g12y4g_inf = subs(g11y4g_inf,a,A);
g13y4g_inf = subs(g12y4g_inf,b,B);
g14y4g_inf = subs(g13y4g_inf,d,D);
g15y4g_inf = subs(g14y4g_inf,x,X);
g16y4g_inf = subs(g15y4g_inf,y,Y);

g12y4h_inf = subs(g11y4h_inf,a,A);
g13y4h_inf = subs(g12y4h_inf,b,B);
g14y4h_inf = subs(g13y4h_inf,d,D);
g15y4h_inf = subs(g14y4h_inf,x,X);
g16y4h_inf = subs(g15y4h_inf,y,Y);

help_a = g9y4 - g9y4a;
check_a = simplify(help_a,'Steps',10)

help_b = g9y4 - g9y4b;
check_b = simplify(help_b,'Steps',10)
 
help_c = g9y4 - g9y4c;
check_c = simplify(help_c,'Steps',10)

help_d = g9y4 - g9y4d;
check_d = simplify(help_d,'Steps',10)

help_e = g9y4 - g9y4e;
check_e = simplify(help_e,'Steps',10)

help_ab_inf = g16y4a_inf - g16y4b_inf;
check_ab_inf = simplify(help_ab_inf,'Steps',10)

help_bc_inf = g16y4b_inf - g16y4c_inf;
check_bc_inf = simplify(help_bc_inf,'Steps',10)

help_bd_inf = g16y4b_inf - g16y4d_inf;
check_bd_inf = simplify(help_bd_inf,'Steps',10)

help_be_inf = g16y4b_inf - g16y4e_inf;
check_be_inf = simplify(help_be_inf,'Steps',10)

help_bf_inf = g16y4b_inf - g16y4f_inf;
check_bf_inf = simplify(help_bf_inf,'Steps',10)

help_bg_inf = g16y4b_inf - g16y4g_inf;
check_bg_inf = simplify(help_bg_inf,'Steps',10)

help_bh_inf = g16y4b_inf - g16y4h_inf;
check_bh_inf = simplify(help_bh_inf,'Steps',10)


